/* WARNING: This file is generated!
 * Do not edit this file, but edit /cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/src/doxygen-1.18.0/src/i18n/config_fr.xml instead and run
 * python configgen.py -wiz /cygdrive/d/a/scallywag/doxygen/doxygen-1.18.0-1.x86_64/src/doxygen-1.18.0/src/i18n/config_fr.xml to regenerate this file!
 */
#include "configdoc.h"
#include "docintf.h"

void addConfigDocs_fr(DocIntf *doc)
{
  doc->setHeader(
              "Ce fichier décrit les paramètres à utiliser par le système de documentation\n"
              "Doxygen (www.doxygen.org) pour un projet.\n"
              "\n"
              "Tout le texte suivant un double dièse (##) est considéré comme un commentaire\n"
              "et est placé devant la balise qu'il précède.\n"
              "\n"
              "Tout le texte suivant un simple dièse (#) est considéré comme un commentaire\n"
              "et sera ignoré. Le format est :\n"
              "TAG = value [value, ...]\n"
              "Pour les listes, des éléments peuvent également être ajoutés en utilisant :\n"
              "TAG += value [value, ...]\n"
              "Les valeurs contenant des espaces doivent être placées entre guillemets (\"\n"
              "\").\n"
              "\n"
              "Remarque :\n"
              "\n"
              "Utilisez Doxygen pour comparer le fichier de configuration utilisé avec le\n"
              "fichier de configuration modèle :\n"
              "doxygen -x [configFile]\n"
              "Utilisez Doxygen pour comparer le fichier de configuration utilisé avec le\n"
              "fichier de configuration modèle sans remplacer les variables d'environnement\n"
              "ou les variables de substitution de type CMake :\n"
              "doxygen -x_noenv [configFile]"
             );
  doc->add(
              "DOXYFILE_ENCODING",
              "Cette balise spécifie l'encodage utilisé pour tous les caractères du fichier\n"
              "de configuration qui suivent. La valeur par défaut est UTF-8, qui est\n"
              "également l'encodage utilisé pour tout le texte avant la première occurrence\n"
              "de cette balise. Doxygen utilise libiconv (ou l'iconv intégré dans libc) pour\n"
              "le transcodage. Voir https://www.gnu.org/software/libiconv/ pour la liste des\n"
              "encodages possibles.\n"
              "La valeur par défaut est : UTF-8."
          );
  doc->add(
              "PROJECT_NAME",
              "La balise PROJECT_NAME est un mot unique (ou une séquence de mots entourés de\n"
              "guillemets doubles, sauf si vous utilisez Doxywizard) qui doit identifier le\n"
              "projet pour lequel la documentation est générée. Ce nom est utilisé dans le\n"
              "titre de la plupart des pages générées et dans quelques autres endroits.\n"
              "La valeur par défaut est : My Project."
          );
  doc->add(
              "PROJECT_NUMBER",
              "La balise PROJECT_NUMBER peut être utilisée pour entrer un numéro de projet ou\n"
              "de révision. Cela peut être utile pour archiver la documentation générée ou si\n"
              "un système de contrôle de version est utilisé."
          );
  doc->add(
              "PROJECT_BRIEF",
              "En utilisant la balise PROJECT_BRIEF, on peut fournir une description\n"
              "optionnelle d'une ligne pour un projet qui apparaît en haut de chaque page et\n"
              "devrait donner aux lecteurs une idée rapide du but du projet. Gardez la\n"
              "description courte."
          );
  doc->add(
              "PROJECT_LOGO",
              "Avec la balise PROJECT_LOGO, on peut spécifier un logo ou une icône qui est\n"
              "inclus dans la documentation. La hauteur maximale du logo ne doit pas dépasser\n"
              "55 pixels et la largeur maximale ne doit pas dépasser 200 pixels. Doxygen\n"
              "copiera le logo dans le répertoire de sortie."
          );
  doc->add(
              "PROJECT_ICON",
              "Avec la balise PROJECT_ICON, on peut spécifier une icône qui est incluse dans\n"
              "les onglets lorsque le document HTML est affiché. Doxygen copiera le logo dans\n"
              "le répertoire de sortie."
          );
  doc->add(
              "OUTPUT_DIRECTORY",
              "La balise OUTPUT_DIRECTORY est utilisée pour spécifier le chemin (relatif ou\n"
              "absolu) dans lequel la documentation générée sera écrite. Si un chemin relatif\n"
              "est entre, il sera relatif à l'emplacement ou Doxygen a été lance. Si laissé\n"
              "vide, le répertoire courant sera utilisé."
          );
  doc->add(
              "CREATE_SUBDIRS",
              "Si la balise CREATE_SUBDIRS est définie à YES, Doxygen créera jusqu'à 4096\n"
              "sous-répertoires (sur 2 niveaux) sous le répertoire de sortie de chaque format\n"
              "de sortie et distribuera les fichiers générés sur ces répertoires. Activer\n"
              "cette option peut être utile lors de l'alimentation de Doxygen avec une grande\n"
              "quantité de fichiers sources, ou mettre tous les fichiers générés dans le même\n"
              "répertoire causerait autrement des problèmes de performance pour le système de\n"
              "fichiers. Ajustez CREATE_SUBDIRS_LEVEL pour contrôler le nombre de sous-\n"
              "répertoires.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "CREATE_SUBDIRS_LEVEL",
              "Contrôle le nombre de sous-répertoires qui seront créés lorsque la balise\n"
              "CREATE_SUBDIRS est définie à YES. Le niveau 0 représente 16 répertoires, et\n"
              "chaque incrément de niveau double le nombre de répertoires, résultant en 4096\n"
              "répertoires au niveau 8 qui est la valeur par défaut et également la valeur\n"
              "maximale. Les sous-répertoires sont organisés sur 2 niveaux, le premier niveau\n"
              "a toujours un nombre fixe de 16 répertoires.\n"
              "Valeur minimum : 0, valeur maximum : 8, valeur par défaut : 8.\n"
              "Cette balise nécessite que la balise CREATE_SUBDIRS soit définie sur YES."
          );
  doc->add(
              "ALLOW_UNICODE_NAMES",
              "Si la balise ALLOW_UNICODE_NAMES est définie à YES, Doxygen permettra aux\n"
              "caractères non-ASCII d'apparaître dans les noms des fichiers générés. Si\n"
              "défini à NO, les caractères non-ASCII seront échappés, par exemple\n"
              "_xE3_x81_x84 sera utilisé pour Unicode U+3044.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "OUTPUT_LANGUAGE",
              "La balise OUTPUT_LANGUAGE est utilisée pour spécifier la langue dans laquelle\n"
              "toute la documentation générée par Doxygen est écrite. Doxygen utilisera cette\n"
              "information pour générer toute la sortie constante dans la langue appropriée.\n"
              "Les valeurs possibles sont :Afrikaans, Arabic, Armenian, Brazilian, Bulgarian,\n"
              "Catalan, Chinese, Chinese-Traditional, Croatian, Czech, Danish, Dutch, English\n"
              "(États-Unis), Esperanto, Farsi (Persan), Finnish, French, German, Greek,\n"
              "Hindi, Hungarian, Indonesian, Italian, Japanese, Japanese-en (Japonais avec\n"
              "messages en anglais), Korean, Korean-en (Coréen avec messages en anglais),\n"
              "Latvian, Lithuanian, Macedonian, Norwegian, Persian (Farsi), Polish,\n"
              "Portuguese, Romanian, Russian, Serbian, Serbian-Cyrillic, Slovak, Slovene,\n"
              "Spanish, Swedish, Turkish, UkrainianetVietnamese.\n"
              "La valeur par défaut est : English."
          );
  doc->add(
              "BRIEF_MEMBER_DESC",
              "Si la balise BRIEF_MEMBER_DESC est définie à YES, Doxygen inclura les\n"
              "descriptions brèves des membres après les membres qui sont listés dans la\n"
              "documentation du fichier et de la classe (similaire à Javadoc). Définir à NO\n"
              "pour désactiver cela.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "REPEAT_BRIEF",
              "Si la balise REPEAT_BRIEF est définie à YES, Doxygen ajoutera la description\n"
              "brève d'un membre ou d'une fonction avant la description détaillée.\n"
              "\n"
              "Remarque: Si HIDE_UNDOC_MEMBERS et BRIEF_MEMBER_DESC sont tous deux définis à\n"
              "NO, les descriptions brèves seront complètement supprimées.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "ABBREVIATE_BRIEF",
              "Cette balise implémente un abréviateur de description brève quasi-intelligent\n"
              "qui est utilisé pour former le texte dans diverses listes. Chaque chaîne de\n"
              "cette liste, si elle est trouvée comme texte de début de la description brève,\n"
              "sera retirée du texte et le résultat, après traitement de toute la liste, est\n"
              "utilisé comme texte annoté. Sinon, la description brève est utilisée telle\n"
              "quelle. Si laissé vide, les valeurs suivantes sont utilisées ($name est\n"
              "automatiquement remplace par le nom de l'entité):The $name class, The $name\n"
              "widget, The $name file, is, provides, specifies, contains, represents, a,\n"
              "anetthe."
          );
  doc->add(
              "ALWAYS_DETAILED_SEC",
              "Si les balises ALWAYS_DETAILED_SEC et REPEAT_BRIEF sont toutes deux définies à\n"
              "YES, alors Doxygen générera une section détaillée même s'il n'y a qu'une\n"
              "description brève.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "INLINE_INHERITED_MEMB",
              "Si la balise INLINE_INHERITED_MEMB est définie à YES, Doxygen affichera tous\n"
              "les membres hérités d'une classe dans la documentation de cette classe comme\n"
              "si ces membres étaient des membres ordinaires de la classe. Les constructeurs,\n"
              "destructeurs et opérateurs d'affectation des classes de base ne seront pas\n"
              "affichés.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "FULL_PATH_NAMES",
              "Si la balise FULL_PATH_NAMES est définie à YES, Doxygen ajoutera le chemin\n"
              "complet avant les noms de fichiers dans la liste des fichiers et dans les\n"
              "fichiers d'en-tête. Si défini à NO, le chemin le plus court qui rend le nom de\n"
              "fichier unique sera utilisé.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "STRIP_FROM_PATH",
              "La balise STRIP_FROM_PATH peut être utilisée pour retirer une partie définie\n"
              "par l'utilisateur du chemin. Le retrait n'est effectue que si l'une des\n"
              "chaînes spécifiées correspond à la partie gauche du chemin. La balise peut\n"
              "être utilisée pour afficher des chemins relatifs dans la liste des fichiers.\n"
              "Si laissé vide, le répertoire à partir duquel Doxygen est lance est utilisé\n"
              "comme chemin a retirer.\n"
              "\n"
              "Remarquez que vous pouvez spécifier des chemins absolus ici, mais aussi des\n"
              "chemins relatifs, qui seront relatifs au répertoire ou Doxygen est lance.\n"
              "Cette balise nécessite que la balise FULL_PATH_NAMES soit définie sur YES."
          );
  doc->add(
              "STRIP_FROM_INC_PATH",
              "La balise STRIP_FROM_INC_PATH peut être utilisée pour retirer une partie\n"
              "définie par l'utilisateur du chemin mentionne dans la documentation d'une\n"
              "classe, qui indique au lecteur quel fichier d'en-tête inclure pour utiliser\n"
              "une classe. Si laissé vide, seul le nom du fichier d'en-tête contenant la\n"
              "définition de la classe est utilisé. Sinon, on devrait spécifier la liste des\n"
              "chemins d'inclusion qui sont normalement passés au compilateur en utilisant\n"
              "l'option -I."
          );
  doc->add(
              "SHORT_NAMES",
              "Si la balise SHORT_NAMES est définie à YES, Doxygen générera des noms de\n"
              "fichiers beaucoup plus courts (mais moins lisibles). Cela peut être utile si\n"
              "votre système de fichiers ne supporte pas les longs noms comme sur DOS, Mac ou\n"
              "CD-ROM.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "JAVADOC_AUTOBRIEF",
              "Si la balise JAVADOC_AUTOBRIEF est définie à YES alors Doxygen interprétera la\n"
              "première ligne (jusqu'au premier point, point d'interrogation ou point\n"
              "d'exclamation) d'un commentaire de style Javadoc comme la description brève.\n"
              "Si défini à NO, le style Javadoc se comportera comme des commentaires de style\n"
              "Qt normaux (requérant donc une commande @brief explicite pour une description\n"
              "brève).\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "JAVADOC_BANNER",
              "Si la balise JAVADOC_BANNER est définie à YES alors Doxygen interprétera une\n"
              "ligne telle que\n"
              "/***************\n"
              "comme étant le début d'une \"bannière\" de commentaire de style Javadoc. Si\n"
              "défini à NO, le style Javadoc se comportera comme des commentaires normaux et\n"
              "Doxygen ne l'interprétera pas.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "QT_AUTOBRIEF",
              "Si la balise QT_AUTOBRIEF est définie à YES alors Doxygen interprétera la\n"
              "première ligne (jusqu'au premier point, point d'interrogation ou point\n"
              "d'exclamation) d'un commentaire de style Qt comme la description brève. Si\n"
              "défini à NO, le style Qt se comportera comme des commentaires de style Qt\n"
              "normaux (requérant donc une commande \\brief explicite pour une description\n"
              "brève).\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "MULTILINE_CPP_IS_BRIEF",
              "La balise MULTILINE_CPP_IS_BRIEF peut être définie à YES pour faire que\n"
              "Doxygen traite un bloc de commentaire spécial C++ multiligne (c'est-à-dire un\n"
              "bloc de commentaires //! ou ///) comme une description brève. C'était le\n"
              "comportement par défaut. Le nouveau défaut est de traiter un bloc de\n"
              "commentaire C++ multiligne comme une description détaillée. Définissez cette\n"
              "balise à YES si vous préférez l'ancien comportement.\n"
              "\n"
              "Remarquez que définir cette balise à YES signifie également que les\n"
              "commentaires Rational Rose ne sont plus reconnus.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "PYTHON_DOCSTRING",
              "Par défaut, les docstrings Python sont affichées comme du texte préformaté et\n"
              "les commandes spéciales de Doxygen ne peuvent pas être utilisées. En\n"
              "définissant PYTHON_DOCSTRING à NO, les commandes spéciales de Doxygen peuvent\n"
              "être utilisées et le contenu des blocs de documentation docstring est affiché\n"
              "comme documentation Doxygen.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "INHERIT_DOCS",
              "Si la balise INHERIT_DOCS est définie à YES alors un membre non documente\n"
              "hérité de la documentation de tout membre documente qu'il re-implémente.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "SEPARATE_MEMBER_PAGES",
              "Si la balise SEPARATE_MEMBER_PAGES est définie à YES alors Doxygen produira\n"
              "une nouvelle page pour chaque membre. Si défini à NO, la documentation d'un\n"
              "membre fera partie du fichier/classe/namespace qui le contient.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "TAB_SIZE",
              "La balise TAB_SIZE peut être utilisée pour définir le nombre d'espaces dans\n"
              "une tabulation. Doxygen utilise cette valeur pour remplacer les tabulations\n"
              "par des espaces dans les fragments de code.\n"
              "Valeur minimum : 1, valeur maximum : 16, valeur par défaut : 4."
          );
  doc->add(
              "ALIASES",
              "Cette balise peut être utilisée pour spécifier un certain nombre d'alias qui\n"
              "agissent comme des commandes dans la documentation. Un alias à la forme:\n"
              "name=value\n"
              "Par exemple, ajouter\n"
              "\"sideeffect=@par Side Effects:^^\"\n"
              "vous permettra de placer la commande \\sideeffect (ou @sideeffect) dans la\n"
              "documentation, ce qui résultera en un paragraphe défini par l'utilisateur avec\n"
              "le titre \"Side Effects:\". Notez que vous ne pouvez pas mettre de \\n dans la\n"
              "partie valeur d'un alias pour insérer des sauts de ligne (dans la sortie\n"
              "résultante). Vous pouvez mettre ^^ dans la partie valeur d'un alias pour\n"
              "insérer un saut de ligne comme si un saut de ligne physique était dans le\n"
              "fichier original.Lorsque vous avez besoin d'un caractère littéral { ou } ou ,\n"
              "dans la valeur d'un alias, vous devez les échapper à l'aide d'une barre\n"
              "oblique inverse (\\). Cela peut entraîner des conflits avec les commandes \\{ et\n"
              "\\}. Pour celles-ci, il est conseillé d'utiliser la version @{ et @} ou\n"
              "d'utiliser une double échappement (\\\\{ et \\\\})."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_FOR_C",
              "Définissez la balise OPTIMIZE_OUTPUT_FOR_C à YES si votre projet consiste\n"
              "uniquement en sources C. Doxygen générera alors une sortie plus adaptée au C.\n"
              "Par exemple, certains des noms utilisés seront différents. La liste de tous\n"
              "les membres sera omise, etc.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_JAVA",
              "Définissez la balise OPTIMIZE_OUTPUT_JAVA à YES si votre projet consiste\n"
              "uniquement en sources Java ou Python. Doxygen générera alors une sortie plus\n"
              "adaptée à ce langage. Par exemple, les namespaces seront présentés comme des\n"
              "packages, les portées qualifiées auront un aspect différent, etc.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "OPTIMIZE_FOR_FORTRAN",
              "Définissez la balise OPTIMIZE_FOR_FORTRAN à YES si votre projet consiste en\n"
              "sources Fortran. Doxygen générera alors une sortie adaptée au Fortran.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_VHDL",
              "Définissez la balise OPTIMIZE_OUTPUT_VHDL à YES si votre projet consiste en\n"
              "sources VHDL. Doxygen générera alors une sortie adaptée au VHDL.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "OPTIMIZE_OUTPUT_SLICE",
              "Définissez la balise OPTIMIZE_OUTPUT_SLICE à YES si votre projet consiste\n"
              "uniquement en sources Slice. Doxygen générera alors une sortie plus adaptée à\n"
              "ce langage. Par exemple, les namespaces seront présentés comme des modules,\n"
              "les types seront séparés en plus de groupes, etc.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "EXTENSION_MAPPING",
              "Doxygen sélectionne l'analyseur à utiliser en fonction de l'extension des\n"
              "fichiers qu'il analyse. Avec cette balise, vous pouvez assigner quel analyseur\n"
              "utiliser pour une extension donnée. Doxygen a une correspondance intégrée,\n"
              "mais vous pouvez la remplacer ou l'étendre en utilisant cette balise. Le\n"
              "format est ext=language, ou ext est une extension de fichier, et language est\n"
              "l'un des analyseurs supportés par Doxygen: IDL, Java, JavaScript, Csharp (C#),\n"
              "C, C++, Lex, D, PHP, md (Markdown), Objective-C, Python, Slice, VHDL, Fortran\n"
              "(Fortran format fixe: FortranFixed, Fortran format libre: FortranFree, Fortran\n"
              "format inconnu: Fortran. Dans ce dernier cas, l'analyseur essaie de deviner si\n"
              "le code est en format fixe ou libre, c'est le défaut pour les fichiers de type\n"
              "Fortran). Par exemple, pour faire que Doxygen traite les fichiers .inc comme\n"
              "des fichiers Fortran (le défaut est PHP), et les fichiers .f comme C (le\n"
              "défaut est Fortran), utilisez: inc=Fortran f=C.\n"
              "\n"
              "Note: Pour les fichiers sans extension, vous pouvez utiliser no_extension\n"
              "comme espace réservé.\n"
              "\n"
              "Notez que pour les extensions personnalisées vous devez également définir\n"
              "FILE_PATTERNS sinon les fichiers ne sont pas lus par Doxygen. Lorsque vous\n"
              "spécifiez no_extension vous devriez ajouter * au FILE_PATTERNS.\n"
              "\n"
              "Notez voir aussi la liste des correspondances d'extension de fichier par\n"
              "défaut."
          );
  doc->add(
              "MARKDOWN_SUPPORT",
              "Si la balise MARKDOWN_SUPPORT est activée alors Doxygen pré-traite tous les\n"
              "commentaires selon le format Markdown, ce qui permet une documentation plus\n"
              "lisible. Voir https://daringfireball.net/projects/markdown/ pour plus de\n"
              "détails. La sortie du traitement Markdown est ensuite traitée par Doxygen,\n"
              "vous pouvez donc mélanger les commandes Doxygen, HTML et XML avec le formatage\n"
              "Markdown. Désactivez uniquement en cas de problèmes de compatibilité\n"
              "ascendante.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "MARKDOWN_STRICT",
              "Si la balise MARKDOWN_STRICT est activée alors Doxygen traite le texte dans\n"
              "les commentaires comme formaté en Markdown aussi dans les cas ou le format de\n"
              "balisage natif de Doxygen entre en conflit avec celui de Markdown. Cela n'est\n"
              "pertinent que dans les cas ou des backticks sont utilisés. Le style de\n"
              "balisage natif de Doxygen permet à un guillemet simple de terminer un fragment\n"
              "de texte commencé par un backtick et de le traiter comme un morceau de texte\n"
              "cité, alors qu'en Markdown un tel fragment est traité comme verbatim et ne se\n"
              "termine que lorsqu'un deuxième backtick correspondant est trouvé. De plus, le\n"
              "format de balisage natif de Doxygen nécessite que les guillemets doubles\n"
              "soient échappés lorsqu'ils apparaissent dans une section backtick, alors que\n"
              "cela n'est pas nécessaire pour Markdown.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise MARKDOWN_SUPPORT soit définie sur YES."
          );
  doc->add(
              "TOC_INCLUDE_HEADINGS",
              "Lorsque la balise TOC_INCLUDE_HEADINGS est définie à une valeur non nulle,\n"
              "tous les titres jusqu'à ce niveau sont automatiquement inclus dans la table\n"
              "des matières, même s'ils n'ont pas d'attribut id.\n"
              "Note : Cette fonctionnalité s'applique actuellement uniquement aux titres\n"
              "Markdown.\n"
              "Valeur minimum : 0, valeur maximum : 99, valeur par défaut : 6.\n"
              "Cette balise nécessite que la balise MARKDOWN_SUPPORT soit définie sur YES."
          );
  doc->add(
              "MARKDOWN_ID_STYLE",
              "La balise MARKDOWN_ID_STYLE peut être utilisée pour spécifier l'algorithme\n"
              "utilisé pour générer les identifiants pour les titres Markdown. Note: Chaque\n"
              "identifiant est unique.\n"
              "Les valeurs possibles sont :DOXYGEN utiliser une chaîne 'autotoc_md' fixe\n"
              "suivie d'un numéro de séquence commençant à 0etGITHUB utiliser la version en\n"
              "minuscules du titre avec tous les espaces remplacés par '-' et les caractères\n"
              "de ponctuation supprimés.\n"
              "La valeur par défaut est : DOXYGEN.\n"
              "Cette balise nécessite que la balise MARKDOWN_SUPPORT soit définie sur YES."
          );
  doc->add(
              "AUTOLINK_SUPPORT",
              "Lorsqu'activé, Doxygen essaie de lier les mots qui correspondent à des classes\n"
              "documentées, ou des namespaces à leur documentation correspondante. Un tel\n"
              "lien peut être empesche dans des cas individuels en mettant un signe % devant\n"
              "le mot ou globalement en définissant AUTOLINK_SUPPORT à NO. Les mots listes\n"
              "dans la balise AUTOLINK_IGNORE_WORDS sont exclus de la liaison automatique.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "AUTOLINK_IGNORE_WORDS",
              "Cette balise spécifie une liste de mots qui, lorsqu'ils correspondent au début\n"
              "d'un mot dans la documentation, supprimeront la génération de liens\n"
              "automatiques, si elle est activée via AUTOLINK_SUPPORT. Cette liste n'affecte\n"
              "pas les liens créés explicitement en utilisant # ou les commandes \\link ou\n"
              "\\ref.\n"
              "Cette balise nécessite que la balise AUTOLINK_SUPPORT soit définie sur YES."
          );
  doc->add(
              "BUILTIN_STL_SUPPORT",
              "Si vous utilisez des classes STL (c'est-à-dire std::string, std::vector, etc.)\n"
              "mais ne voulez pas inclure (un fichier de balises pour) les sources STL comme\n"
              "entrée, alors vous devriez définir cette balise à YES afin de laisser Doxygen\n"
              "faire correspondre les déclarations et définitions de fonctions dont les\n"
              "arguments contiennent des classes STL (par ex. func(std::string); versus\n"
              "func(std::string) {}). Cela rend également les diagrammes d'héritage et de\n"
              "collaboration qui impliquent des classes STL plus complets et précis.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "CPP_CLI_SUPPORT",
              "Si vous utilisez le langage C++/CLI de Microsoft, vous devriez définir cette\n"
              "option à YES pour activer le support de l'analyse.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "SIP_SUPPORT",
              "Définissez la balise SIP_SUPPORT à YES si votre projet consiste uniquement en\n"
              "sources sip (see:\n"
              "https://www.riverbankcomputing.com/software). Doxygen les analysera comme du\n"
              "C++ normal mais supposera que toutes les classes utilisent l'héritage public\n"
              "au lieu de l'héritage prive lorsqu'aucun mot-cle de protection explicite n'est\n"
              "présent.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "IDL_PROPERTY_SUPPORT",
              "Pour l'IDL de Microsoft, il y a des attributs propget et propput pour indiquer\n"
              "les méthodes getter et setter pour une propriété. Définir cette option à YES\n"
              "fera que Doxygen remplacera les méthodes get et set par une propriété dans la\n"
              "documentation. Cela ne fonctionnera que si les méthodes obtiennent ou\n"
              "definissent effectivement un type simple. Si ce n'est pas le cas, ou si vous\n"
              "voulez montrer les méthodes quand même, vous devriez définir cette option à\n"
              "NO.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "DISTRIBUTE_GROUP_DOC",
              "Si le regroupement de membres est utilisé dans la documentation et que la\n"
              "balise DISTRIBUTE_GROUP_DOC est définie à YES alors Doxygen reutilisera la\n"
              "documentation du premier membre du groupe (s'il y en a) pour les autres\n"
              "membres du groupe. Par défaut, tous les membres d'un groupe doivent être\n"
              "documentés explicitement.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "GROUP_NESTED_COMPOUNDS",
              "Si on ajoute une struct ou une classe à un groupe et que cette option est\n"
              "activée, alors toute classe ou struct imbriquée est également ajoutée au même\n"
              "groupe. Par défaut cette option est désactivée et on doit ajouter les composes\n"
              "imbriques explicitement via \\ingroup.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "SUBGROUPING",
              "Définissez la balise SUBGROUPING à YES pour permettre aux groupes de membres\n"
              "de classe du même type (par exemple un groupe de fonctions publiques) d'être\n"
              "mis comme sous-groupe de ce type (par exemple sous la section Fonctions\n"
              "Publiques). Définissez-la à NO pour empêcher le sous-groupement.\n"
              "Alternativement, cela peut être fait par classe en utilisant la commande\n"
              "\\nosubgrouping.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "INLINE_GROUPED_CLASSES",
              "Lorsque la balise INLINE_GROUPED_CLASSES est définie à YES, les classes,\n"
              "structs et unions sont affichés à l'intérieur du groupe dans lequel ils sont\n"
              "inclus (par exemple en utilisant \\ingroup) au lieu d'une page séparée (pour\n"
              "HTML et pages de manuel) ou section (pour LaTeX et RTF).\n"
              "\n"
              "Notez que cette fonctionnalité ne fonctionne pas en combinaison avec\n"
              "SEPARATE_MEMBER_PAGES.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "INLINE_SIMPLE_STRUCTS",
              "Lorsque la balise INLINE_SIMPLE_STRUCTS est définie à YES, les structs,\n"
              "classes et unions avec uniquement des champs de données publics ou des champs\n"
              "typedef simples seront affichés en ligne dans la documentation de la portée\n"
              "dans laquelle ils sont définis (c'est-à-dire documentation de fichier,\n"
              "namespace ou groupe), à condition que cette portée soit documentée. Si défini\n"
              "à NO, les structs, classes et unions sont affichés sur une page séparée (pour\n"
              "HTML et pages de manuel) ou section (pour LaTeX et RTF).\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "TYPEDEF_HIDES_STRUCT",
              "Lorsque la balise TYPEDEF_HIDES_STRUCT est activée, un typedef d'une struct,\n"
              "union ou enum est documente comme struct, union ou enum avec le nom du\n"
              "typedef. Donc typedef struct TypeS {} TypeT apparaîtra dans la documentation\n"
              "comme une struct avec le nom TypeT. Lorsque désactivé, le typedef apparaîtra\n"
              "comme un membre d'un fichier, namespace ou classe. Et la struct sera nommée\n"
              "TypeS. Cela peut typiquement être utile pour le code C au cas ou la convention\n"
              "de codage dicte que tous les types composes sont typedefes et seul le typedef\n"
              "est référence, jamais le nom de tag.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "LOOKUP_CACHE_SIZE",
              "La taille du cache de recherche de symboles peut être définie en utilisant\n"
              "LOOKUP_CACHE_SIZE. Ce cache est utilisé pour résoudre les symboles donnes leur\n"
              "nom et portée. Puisque cela peut être un processus couteux et souvent le même\n"
              "symbole apparaît plusieurs fois dans le code, Doxygen garde un cache de\n"
              "symboles pre-resolus. Si le cache est trop petit Doxygen deviendra plus lent.\n"
              "Si le cache est trop grand, la mémoire est gaspillée. La taille du cache est\n"
              "donnée par cette formule: 2^(16+LOOKUP_CACHE_SIZE). La plage valide est 0..9,\n"
              "le défaut est 0, correspondant à une taille de cache de 2^16=65536 symboles. à\n"
              "la fin d'une exécution Doxygen rapportera l'utilisation du cache et suggerera\n"
              "la taille de cache optimale d'un point de vue vitesse.\n"
              "Valeur minimum : 0, valeur maximum : 9, valeur par défaut : 0."
          );
  doc->add(
              "NUM_PROC_THREADS",
              "Le NUM_PROC_THREADS spécifie le nombre de threads que Doxygen est autorisé à\n"
              "utiliser pendant le traitement. Lorsque défini à 0 Doxygen se basera sur le\n"
              "nombre de coeurs disponibles dans le système. Vous pouvez le définir\n"
              "explicitement à une valeur supérieure à 0 pour avoir plus de contrôle sur\n"
              "l'équilibre entre la charge CPU et la vitesse de traitement. Pour le moment\n"
              "seul le traitement d'entrée peut être fait en utilisant plusieurs threads.\n"
              "Puisque c'est encore une fonctionnalité expérimentale, le défaut est défini à\n"
              "1, ce qui désactive effectivement le traitement parallele. Veuillez signaler\n"
              "tout problème que vous rencontrez. La génération de graphes dot en parallele\n"
              "est contrôlée par le paramètre DOT_NUM_THREADS.\n"
              "Valeur minimum : 0, valeur maximum : 512, valeur par défaut : 1."
          );
  doc->add(
              "TIMESTAMP",
              "Si la balise TIMESTAMP est définie différemment de NO alors chaque page\n"
              "générée contiendra la date ou la date et l'heure ou la page a été générée.\n"
              "Définir cela à NO peut aider lors de la comparaison de la sortie de plusieurs\n"
              "exécutions.\n"
              "Les valeurs possibles sont :YES, NO, DATETIMEetDATE.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "EXTRACT_ALL",
              "Si la balise EXTRACT_ALL est définie à YES, Doxygen supposera que toutes les\n"
              "entités dans la documentation sont documentées, même si aucune documentation\n"
              "n'était disponible. Les membres prives de classe et les membres statiques de\n"
              "fichier seront cachés sauf si les balises EXTRACT_PRIVATE respectivement\n"
              "EXTRACT_STATIC sont définies à YES.\n"
              "Note : Cela desactivera également les avertissements sur les membres non\n"
              "documentés qui sont normalement produits lorsque WARNINGS est défini à YES.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "EXTRACT_PRIVATE",
              "Si la balise EXTRACT_PRIVATE est définie à YES, tous les membres prives d'une\n"
              "classe seront inclus dans la documentation.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "EXTRACT_PRIV_VIRTUAL",
              "Si la balise EXTRACT_PRIV_VIRTUAL est définie à YES, les méthodes virtuelles\n"
              "prives documentées d'une classe seront incluses dans la documentation.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "EXTRACT_PACKAGE",
              "Si la balise EXTRACT_PACKAGE est définie à YES, tous les membres avec une\n"
              "portée package ou interne seront inclus dans la documentation.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "EXTRACT_STATIC",
              "Si la balise EXTRACT_STATIC est définie à YES, tous les membres statiques d'un\n"
              "fichier seront inclus dans la documentation.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "EXTRACT_LOCAL_CLASSES",
              "Si la balise EXTRACT_LOCAL_CLASSES est définie à YES, les classes (et structs)\n"
              "définies localement dans les fichiers sources seront incluses dans la\n"
              "documentation. Si défini à NO, seules les classes définies dans les fichiers\n"
              "d'en-tête sont incluses. N'a aucun effet pour les sources Java.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "EXTRACT_LOCAL_METHODS",
              "Ce drapeau n'est utile que pour le code Objective-C. Si défini à YES, les\n"
              "méthodes locales, qui sont définies dans la section d'implémentation mais pas\n"
              "dans l'interface sont incluses dans la documentation. Si défini à NO, seules\n"
              "les méthodes dans l'interface sont incluses.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "EXTRACT_ANON_NSPACES",
              "Si ce drapeau est défini à YES, les membres des namespaces anonymes seront\n"
              "extraits et apparaîtront dans la documentation comme un namespace appelé\n"
              "'anonymous_namespace{file}', ou file sera remplace par le nom de base du\n"
              "fichier qui contient le namespace anonyme. Par défaut les namespaces anonymes\n"
              "sont cachés.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "RESOLVE_UNNAMED_PARAMS",
              "Si ce drapeau est défini à YES, le nom d'un paramètre sans nom dans une\n"
              "déclaration sera détermine par la définition correspondante. Par défaut les\n"
              "paramètres sans nom restent sans nom dans la sortie.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "HIDE_UNDOC_MEMBERS",
              "Si la balise HIDE_UNDOC_MEMBERS est définie à YES, Doxygen cachera tous les\n"
              "membres non documentés à l'intérieur des classes ou fichiers documentés. Si\n"
              "défini à NO ces membres seront inclus dans les différents aperçus, mais aucune\n"
              "section de documentation n'est générée. Cette option n'a aucun effet si\n"
              "EXTRACT_ALL est activé.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "HIDE_UNDOC_CLASSES",
              "Si la balise HIDE_UNDOC_CLASSES est définie à YES, Doxygen cachera toutes les\n"
              "classes non documentées qui sont normalement visibles dans la hiérarchie de\n"
              "classes. Si défini à NO, ces classes seront incluses dans les différents\n"
              "aperçus. Cette option cachera également les concepts C++ non documentés si\n"
              "active. Cette option n'a aucun effet si EXTRACT_ALL est activé.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "HIDE_UNDOC_NAMESPACES",
              "Si la balise HIDE_UNDOC_NAMESPACES est définie à YES, Doxygen cachera tous les\n"
              "namespaces non documentés qui sont normalement visibles dans la hiérarchie des\n"
              "namespaces. Si défini à NO, ces namespaces seront inclus dans les différents\n"
              "aperçus. Cette option n'a aucun effet si EXTRACT_ALL est activé.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "HIDE_FRIEND_COMPOUNDS",
              "Si la balise HIDE_FRIEND_COMPOUNDS est définie à YES, Doxygen cachera toutes\n"
              "les déclarations friend. Si défini à NO, ces déclarations seront incluses dans\n"
              "la documentation.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "HIDE_IN_BODY_DOCS",
              "Si la balise HIDE_IN_BODY_DOCS est définie à YES, Doxygen cachera tous les\n"
              "blocs de documentation trouvés à l'intérieur du corps d'une fonction. Si\n"
              "défini à NO, ces blocs seront ajoutés au bloc de documentation détaillé de la\n"
              "fonction.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "INTERNAL_DOCS",
              "La balise INTERNAL_DOCS détermine si la documentation qui est tapée après une\n"
              "commande \\internal est incluse. Si la balise est définie à NO alors la\n"
              "documentation sera exclue. Définissez-la à YES pour inclure la documentation\n"
              "interne.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "CASE_SENSE_NAMES",
              "Avec le reglage correct de l'option CASE_SENSE_NAMES, Doxygen sera mieux à\n"
              "même de correspondre aux capacites du système de fichiers sous-jacent. Si le\n"
              "système de fichiers est sensible à la casse (c'est-à-dire qu'il supporte des\n"
              "fichiers dans le même répertoire dont les noms ne différent que par la casse),\n"
              "l'option doit être définie à YES pour traiter correctement ces fichiers s'ils\n"
              "apparaissent dans l'entrée. Pour les systèmes de fichiers qui ne sont pas\n"
              "sensibles à la casse, l'option devrait être définie à NO pour traiter\n"
              "correctement les fichiers de sortie écrits pour des symboles qui ne différent\n"
              "que par la casse, comme pour deux classes, une nommée CLASS et l'autre nommée\n"
              "Class, et pour supporter également les références aux fichiers sans avoir a\n"
              "spécifier la casse exacte correspondante. Sur Windows (y compris Cygwin) et\n"
              "macOS, les utilisateurs devraient généralement définir cette option à NO,\n"
              "alors que sur Linux ou d'autres variantes Unix, elle devrait généralement être\n"
              "définie à YES.\n"
              "Les valeurs possibles sont :SYSTEM, NOetYES.\n"
              "La valeur par défaut est : SYSTEM."
          );
  doc->add(
              "HIDE_SCOPE_NAMES",
              "Si la balise HIDE_SCOPE_NAMES est définie à NO alors Doxygen affichera les\n"
              "membres avec leurs portées de classe et de namespace complètes dans la\n"
              "documentation. Si défini à YES, la portée sera cachée.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "HIDE_COMPOUND_REFERENCE",
              "Si la balise HIDE_COMPOUND_REFERENCE est définie à NO (défaut) alors Doxygen\n"
              "ajoutera du texte supplémentaire au titre d'une page, tel que Class Référence.\n"
              "Si défini à YES la référence du compose sera cachée.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "SHOW_HEADERFILE",
              "Si la balise SHOW_HEADERFILE est définie à YES alors la documentation d'une\n"
              "classe montrera quel fichier doit être inclus pour utiliser la classe.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "SHOW_INCLUDE_FILES",
              "Si la balise SHOW_INCLUDE_FILES est définie à YES alors Doxygen mettra une\n"
              "liste des fichiers qui sont inclus par un fichier dans la documentation de ce\n"
              "fichier.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "SHOW_GROUPED_MEMB_INC",
              "Si la balise SHOW_GROUPED_MEMB_INC est définie à YES alors Doxygen ajoutera\n"
              "pour chaque membre groupe une instruction d'inclusion à la documentation,\n"
              "indiquant au lecteur quel fichier inclure pour utiliser le membre.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "FORCE_LOCAL_INCLUDES",
              "Si la balise FORCE_LOCAL_INCLUDES est définie à YES alors Doxygen listera les\n"
              "fichiers d'inclusion avec des guillemets doubles dans la documentation plutôt\n"
              "qu'avec des chevrons.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "INLINE_INFO",
              "Si la balise INLINE_INFO est définie à YES alors une étiquette [inline] est\n"
              "insérée dans la documentation pour les membres inline.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "SORT_MEMBER_DOCS",
              "Si la balise SORT_MEMBER_DOCS est définie à YES alors Doxygen triera la\n"
              "documentation (détaillée) des membres de fichier et de classe alphabétiquement\n"
              "par nom de membre. Si défini à NO, les membres apparaîtront dans l'ordre de\n"
              "déclaration.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "SORT_BRIEF_DOCS",
              "Si la balise SORT_BRIEF_DOCS est définie à YES alors Doxygen triera les\n"
              "descriptions brèves des membres de fichier, namespace et classe\n"
              "alphabétiquement par nom de membre. Si défini à NO, les membres apparaîtront\n"
              "dans l'ordre de déclaration. Notez que cela influencera également l'ordre des\n"
              "classes dans la liste des classes.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "SORT_MEMBERS_CTORS_1ST",
              "Si la balise SORT_MEMBERS_CTORS_1ST est définie à YES alors Doxygen triera la\n"
              "documentation (brève et détaillée) des membres de classe de sorte que les\n"
              "constructeurs et destructeurs soient listes en premier. Si défini à NO les\n"
              "constructeurs apparaîtront dans les ordres respectifs définis par\n"
              "SORT_BRIEF_DOCS et SORT_MEMBER_DOCS.\n"
              "Note : Si SORT_BRIEF_DOCS est défini à NO cette option est ignorée pour le tri\n"
              "de la documentation brève des membres.\n"
              "Note : Si SORT_MEMBER_DOCS est défini à NO cette option est ignorée pour le\n"
              "tri de la documentation détaillée des membres.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "SORT_GROUP_NAMES",
              "Si la balise SORT_GROUP_NAMES est définie à YES alors Doxygen triera la\n"
              "hiérarchie des noms de groupes en ordre alphabetique. Si défini à NO les noms\n"
              "de groupes apparaîtront dans leur ordre défini.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "SORT_BY_SCOPE_NAME",
              "Si la balise SORT_BY_SCOPE_NAME est définie à YES, la liste des classes sera\n"
              "triée par noms complètement qualifies, y compris les namespaces. Si défini à\n"
              "NO, la liste des classes sera triée uniquement par nom de classe, sans inclure\n"
              "la partie namespace.\n"
              "Note : Cette option n'est pas tres utile si HIDE_SCOPE_NAMES est défini à YES.\n"
              "Note : Cette option s'applique uniquement à la liste des classes, pas à la\n"
              "liste alphabetique.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "STRICT_PROTO_MATCHING",
              "Si l'option STRICT_PROTO_MATCHING est activée et que Doxygen échoue à faire\n"
              "une résolution de type correcte de tous les paramètres d'une fonction, il\n"
              "rejettera une correspondance entre le prototype et l'implémentation d'une\n"
              "fonction membre même s'il n'y a qu'un seul candidat ou s'il est evident quel\n"
              "candidat choisir en faisant une simple correspondance de chaîne. En\n"
              "desactivant STRICT_PROTO_MATCHING, Doxygen acceptera toujours une\n"
              "correspondance entre prototype et implémentation dans de tels cas.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "GENERATE_TODOLIST",
              "La balise GENERATE_TODOLIST peut être utilisée pour activer (YES) ou\n"
              "désactiver (NO) la liste des taches. Cette liste est créée en mettant des\n"
              "commandes \\todo dans la documentation.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "GENERATE_TESTLIST",
              "La balise GENERATE_TESTLIST peut être utilisée pour activer (YES) ou\n"
              "désactiver (NO) la liste des tests. Cette liste est créée en mettant des\n"
              "commandes \\test dans la documentation.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "GENERATE_BUGLIST",
              "La balise GENERATE_BUGLIST peut être utilisée pour activer (YES) ou désactiver\n"
              "(NO) la liste des bugs. Cette liste est créée en mettant des commandes \\bug\n"
              "dans la documentation.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "GENERATE_DEPRECATEDLIST",
              "La balise GENERATE_DEPRECATEDLIST peut être utilisée pour activer (YES) ou\n"
              "désactiver (NO) la liste des éléments deprecies. Cette liste est créée en\n"
              "mettant des commandes \\deprecated dans la documentation.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "GENERATE_REQUIREMENTS",
              "La balise GENERATE_REQUIREMENTS peut être utilisée pour activer (YES) ou\n"
              "désactiver (NO) la page des exigences. Lorsqu'activée, cette page est\n"
              "automatiquement créée lorsqu'au moins un bloc de commentaire avec une commande\n"
              "\\requirement apparaît dans l'entrée.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "REQ_TRACEABILITY_INFO",
              "La balise REQ_TRACEABILITY_INFO contrôle si les informations de traçabilité\n"
              "sont affichées sur la page des exigences (pertinent uniquement lors de\n"
              "l'utilisation de blocs de commentaire \\requirement). Le paramètre NO\n"
              "desactivera complètement les informations de traçabilité. Le paramètre\n"
              "UNSATISFIED_ONLY affichera une liste des exigences qui manquent d'une relation\n"
              "satisfies (via la commande: \\satisfies). De même le paramètre UNVERIFIED_ONLY\n"
              "affichera une liste des exigences qui manquent d'une relation verifies (via la\n"
              "commande: \\verifies). Définir la balise à YES (le défaut) affichera les deux\n"
              "listes si applicable.\n"
              "Les valeurs possibles sont :YES, NO, UNSATISFIED_ONLYetUNVERIFIED_ONLY.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise GENERATE_REQUIREMENTS soit définie sur\n"
              "YES."
          );
  doc->add(
              "ENABLED_SECTIONS",
              "La balise ENABLED_SECTIONS peut être utilisée pour activer des sections de\n"
              "documentation conditionnelles, marquées par \\if <section_label> ... \\endif et\n"
              "\\cond <section_label> ... \\endcond."
          );
  doc->add(
              "MAX_INITIALIZER_LINES",
              "La balise MAX_INITIALIZER_LINES détermine le nombre maximal de lignes que la\n"
              "valeur initiale d'une variable ou macro / define peut avoir pour apparaître\n"
              "dans la documentation. Si l'initialiseur consiste en plus de lignes que\n"
              "spécifie ici, il sera cache. Utilisez une valeur de 0 pour cacher complètement\n"
              "les initialiseurs. L'apparence de la valeur des variables individuelles et\n"
              "macros / defines peut être contrôlée en utilisant la commande \\showinitializer\n"
              "ou \\hideinitializer dans la documentation indépendamment de ce paramètre.\n"
              "Valeur minimum : 0, valeur maximum : 10000, valeur par défaut : 30."
          );
  doc->add(
              "SHOW_USED_FILES",
              "Définissez la balise SHOW_USED_FILES à NO pour désactiver la liste des\n"
              "fichiers générés au bas de la documentation des classes et structs. Si défini\n"
              "à YES, la liste mentionnera les fichiers qui ont été utilisés pour générer la\n"
              "documentation.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "SHOW_FILES",
              "Définissez la balise SHOW_FILES à NO pour désactiver la génération de la page\n"
              "Fichiers. Cela supprimera l'entrée Fichiers de l'Index Rapide et de la Vue\n"
              "Arborescente des Dossiers (si spécifie).\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "SHOW_NAMESPACES",
              "Définissez la balise SHOW_NAMESPACES à NO pour désactiver la génération de la\n"
              "page Namespaces. Cela supprimera l'entrée Namespaces de l'Index Rapide et de\n"
              "la Vue Arborescente des Dossiers (si spécifie).\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "FILE_VERSION_FILTER",
              "La balise FILE_VERSION_FILTER peut être utilisée pour spécifier un programme\n"
              "ou script que Doxygen devrait invoquer pour obtenir la version actuelle de\n"
              "chaque fichier (généralement à partir du système de contrôle de version).\n"
              "Doxygen invoquera le programme en executant (via popen()) la commande command\n"
              "input_file, ou command est la valeur de la balise FILE_VERSION_FILTER, et\n"
              "input_file est le nom d'un fichier d'entrée fourni par Doxygen. Ce que le\n"
              "programme écrit sur la sortie standard est utilisé comme version de\n"
              "fichier.Pour un exemple, consultez la documentation."
          );
  doc->add(
              "LAYOUT_FILE",
              "La balise LAYOUT_FILE peut être utilisée pour spécifier un fichier de mise en\n"
              "page qui sera analysé par Doxygen. Le fichier de mise en page contrôle la\n"
              "structure globale des fichiers de sortie générés d'une manière indépendante du\n"
              "format de sortie. Pour créer le fichier de mise en page qui représente les\n"
              "valeurs par défaut de Doxygen, exécutez Doxygen avec l'option -l. Vous pouvez\n"
              "optionnellement spécifier un nom de fichier après l'option, si omis\n"
              "DoxygenLayout.xml sera utilisé comme nom du fichier de mise en page. Voir\n"
              "aussi la section \"Changing the layout of pages\" pour plus d'informations.\n"
              "\n"
              "Notez que si vous exécutez Doxygen à partir d'un répertoire contenant un\n"
              "fichier appelé DoxygenLayout.xml, Doxygen l'analysera automatiquement même si\n"
              "la balise LAYOUT_FILE est laissée vide."
          );
  doc->add(
              "CITE_BIB_FILES",
              "La balise CITE_BIB_FILES peut être utilisée pour spécifier un ou plusieurs\n"
              "fichiers bib contenant les définitions de référence. Cela doit être une liste\n"
              "de fichiers .bib. L'extension .bib est automatiquement ajoutée si omise. Cela\n"
              "nécessite que l'outil bibtex soit installe. Voir aussi\n"
              "https://en.wikipedia.org/wiki/BibTeX pour plus d'infos. Pour LaTeX le style de\n"
              "la bibliographie peut être contrôle en utilisant LATEX_BIB_STYLE. Pour\n"
              "utiliser cette fonctionnalité vous avez besoin de bibtex et perl disponibles\n"
              "dans le chemin de recherche. Voir aussi \\cite pour plus d'infos sur la\n"
              "création de références."
          );
  doc->add(
              "EXTERNAL_TOOL_PATH",
              "La balise EXTERNAL_TOOL_PATH peut être utilisée pour étendre le chemin de\n"
              "recherche (variable d'environnement PATH) afin que des outils externes tels\n"
              "que latex et gs puissent être trouvés.\n"
              "Note : Les répertoires spécifiés avec EXTERNAL_TOOL_PATH sont ajoutés devant\n"
              "le chemin déjà spécifie par la variable PATH, et sont ajoutés dans l'ordre\n"
              "spécifie.\n"
              "Note : Cette option est particulièrement utile pour macOS version 14 (Sonoma)\n"
              "et supérieures, lors de l'exécution de Doxygen depuis Doxywizard, car dans ce\n"
              "cas toutes les modifications définies par l'utilisateur du PATH sont ignorées.\n"
              "Un exemple typique sur macOS est de définir\n"
              "EXTERNAL_TOOL_PATH = /Library/TeX/texbin /usr/local/bin\n"
              "avec le chemin standard, le chemin de recherche complet utilisé par doxygen\n"
              "lors du lancement d'outils externes deviendra alors\n"
              "PATH=/Library/TeX/texbin:/usr/local/bin:/usr/bin:/bin:/usr/sbin:/sbin"
          );
  doc->add(
              "QUIET",
              "La balise QUIET peut être utilisée pour activer/désactiver les messages qui\n"
              "sont générés vers la sortie standard par Doxygen. Si QUIET est défini à YES\n"
              "cela implique que les messages sont désactivés.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "WARNINGS",
              "La balise WARNINGS peut être utilisée pour activer/désactiver les messages\n"
              "d'avertissement qui sont générés vers la sortie d'erreur standard (stderr) par\n"
              "Doxygen. Si WARNINGS est défini à YES cela implique que les avertissements\n"
              "sont activés.\n"
              "\n"
              "Conseil: Activez les avertissements pendant l'écriture de la documentation.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "WARN_IF_UNDOCUMENTED",
              "Si la balise WARN_IF_UNDOCUMENTED est définie à YES alors Doxygen générera des\n"
              "avertissements pour les membres non documentés. Si EXTRACT_ALL est défini à\n"
              "YES alors ce drapeau sera automatiquement désactivé.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "WARN_IF_DOC_ERROR",
              "Si la balise WARN_IF_DOC_ERROR est définie à YES, Doxygen générera des\n"
              "avertissements pour les erreurs potentielles dans la documentation, comme\n"
              "documenter certains paramètres dans une fonction documentée deux fois, ou\n"
              "documenter des paramètres qui n'existent pas ou utiliser incorrectement les\n"
              "commandes de balisage.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "WARN_IF_INCOMPLETE_DOC",
              "Si WARN_IF_INCOMPLETE_DOC est défini à YES, Doxygen avertira des\n"
              "documentations de paramètres de fonction incomplètes. Si défini à NO, Doxygen\n"
              "acceptera que certains paramètres n'aient pas de documentation sans\n"
              "avertissement.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "WARN_NO_PARAMDOC",
              "Cette option WARN_NO_PARAMDOC peut être activée pour obtenir des\n"
              "avertissements pour les fonctions qui sont documentées, mais qui n'ont pas de\n"
              "documentation pour leurs paramètres ou valeur de retour. Si défini à NO,\n"
              "Doxygen avertira uniquement des erreurs de documentation de paramètres, mais\n"
              "pas de l'absence de documentation. Si EXTRACT_ALL est défini à YES alors ce\n"
              "drapeau sera automatiquement désactivé. Voir aussi WARN_IF_INCOMPLETE_DOC\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "WARN_IF_UNDOC_ENUM_VAL",
              "Si l'option WARN_IF_UNDOC_ENUM_VAL est définie à YES, Doxygen avertira des\n"
              "valeurs d'énumération non documentées. Si défini à NO, Doxygen acceptera les\n"
              "valeurs d'énumération non documentées. Si EXTRACT_ALL est défini à YES alors\n"
              "ce drapeau sera automatiquement désactivé.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "WARN_LAYOUT_FILE",
              "Si l'option WARN_LAYOUT_FILE est définie à YES, Doxygen avertira des problèmes\n"
              "trouvés lors de l'analyse du fichier de mise en page défini par l'utilisateur,\n"
              "tels que des éléments manquants ou incorrects. Voir aussi LAYOUT_FILE pour\n"
              "plus de détails. Si défini à NO, les problèmes avec le fichier de mise en page\n"
              "seront supprimés.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "WARN_AS_ERROR",
              "Si la balise WARN_AS_ERROR est définie à YES alors Doxygen s'arrêtera\n"
              "immediatement lorsqu'un avertissement est rencontre. Si la balise\n"
              "WARN_AS_ERROR est définie à FAIL_ON_WARNINGS alors Doxygen continuera à\n"
              "s'exécuter comme si la balise WARN_AS_ERROR était définie à NO, mais à la fin\n"
              "du processus Doxygen retournera un statut non nul. Si la balise WARN_AS_ERROR\n"
              "est définie à FAIL_ON_WARNINGS_PRINT alors Doxygen se comporte comme\n"
              "FAIL_ON_WARNINGS mais au cas ou aucun WARN_LOGFILE n'est défini Doxygen\n"
              "n'ecrira pas les messages d'avertissement entre les autres messages mais les\n"
              "ecrira à la fin d'une exécution, au cas ou un WARN_LOGFILE est défini les\n"
              "messages d'avertissement seront en plus d'être dans le fichier défini\n"
              "également affichés à la fin d'une exécution, sauf si le WARN_LOGFILE est\n"
              "défini comme - c'est-à-dire la sortie standard (stdout) dans ce cas le\n"
              "comportement restera comme avec le paramètre FAIL_ON_WARNINGS.\n"
              "Les valeurs possibles sont :NO, YES, FAIL_ON_WARNINGSetFAIL_ON_WARNINGS_PRINT.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "WARN_FORMAT",
              "La balise WARN_FORMAT détermine le format des messages d'avertissement que\n"
              "Doxygen peut produire. La chaîne doit contenir les balises $file, $line, et\n"
              "$text, qui seront remplacées par le fichier et le numéro de ligne d'ou\n"
              "l'avertissement a originate et le texte de l'avertissement. Optionnellement le\n"
              "format peut contenir $version, qui sera remplace par la version du fichier (si\n"
              "elle a pu être obtenue via FILE_VERSION_FILTER)\n"
              "Voir aussi : WARN_LINE_FORMAT\n"
              "La valeur par défaut est : $file:$line: $text."
          );
  doc->add(
              "WARN_LINE_FORMAT",
              "Dans la partie $text de la commande WARN_FORMAT il est possible qu'une\n"
              "référence à un endroit plus spécifique soit donnée. Pour faciliter le saut à\n"
              "cet endroit (en dehors de Doxygen) l'utilisateur peut définir une chaîne\n"
              "\"couper\" / \"coller\" personnalisée. Exemple:\n"
              "WARN_LINE_FORMAT = \"'vi $file +$line'\"\n"
              "Voir aussi : WARN_FORMAT\n"
              "La valeur par défaut est : at line $line of file $file."
          );
  doc->add(
              "WARN_LOGFILE",
              "La balise WARN_LOGFILE peut être utilisée pour spécifier un fichier dans\n"
              "lequel les messages d'avertissement et d'erreur doivent être écrits. Si\n"
              "laissée vide, la sortie est écrite vers la sortie d'erreur standard (stderr).\n"
              "Au cas ou le fichier spécifie ne peut pas être ouvert pour écriture, les\n"
              "messages d'avertissement et d'erreur sont écrits vers la sortie d'erreur\n"
              "standard. Lorsqu'un fichier - est spécifié, les messages d'avertissement et\n"
              "d'erreur sont écrits vers la sortie standard (stdout)."
          );
  doc->add(
              "INPUT",
              "La balise INPUT est utilisée pour spécifier les fichiers et/ou répertoires qui\n"
              "contiennent les fichiers sources documentés. Vous pouvez entrer des noms de\n"
              "fichiers comme myfile.cpp ou des répertoires comme /usr/src/myproject. Separez\n"
              "les fichiers ou répertoires par des espaces. Voir aussi FILE_PATTERNS et\n"
              "EXTENSION_MAPPING\n"
              "Note : Si cette balise est vide, le répertoire courant est recherche."
          );
  doc->add(
              "INPUT_ENCODING",
              "Cette balise peut être utilisée pour spécifier l'encodage de caractères des\n"
              "fichiers sources que Doxygen analyse. Interne Doxygen utilise l'encodage\n"
              "UTF-8. Doxygen utilise libiconv (ou le iconv intégré dans libc) pour le\n"
              "transcodage. Voir la documentation libiconv (see:\n"
              "https://www.gnu.org/software/libiconv/) pour la liste des encodages possibles.\n"
              "Voir aussi : INPUT_FILE_ENCODING\n"
              "La valeur par défaut est : UTF-8."
          );
  doc->add(
              "INPUT_FILE_ENCODING",
              "Cette balise peut être utilisée pour spécifier l'encodage de caractères des\n"
              "fichiers sources que Doxygen analyse. La balise INPUT_FILE_ENCODING peut être\n"
              "utilisée pour spécifier l'encodage de caractères sur une base par modèle de\n"
              "fichier. Doxygen comparera le nom du fichier avec chaque modèle et appliquera\n"
              "l'encodage au lieu du INPUT_ENCODING par défaut s'il y a une correspondance.\n"
              "Les encodages de caractères sont une liste de la forme: modèle=encodage (comme\n"
              "*.php=ISO-8859-1).\n"
              "Voir aussi : INPUT_ENCODING pour plus d'informations sur les encodages\n"
              "supportés."
          );
  doc->add(
              "FILE_PATTERNS",
              "Si la valeur de la balise INPUT contient des répertoires, vous pouvez utiliser\n"
              "la balise FILE_PATTERNS pour spécifier un ou plusieurs modèles de caractères\n"
              "generiques (comme *.cpp et *.h) pour filtrer les fichiers sources dans les\n"
              "répertoires.\n"
              "\n"
              "Notez que pour les extensions personnalisées ou non directement supportées\n"
              "vous devez également définir EXTENSION_MAPPING pour l'extension sinon les\n"
              "fichiers ne sont pas lus par Doxygen.\n"
              "\n"
              "Notez que la liste des modèles de fichiers vérifiés par défaut peut différer\n"
              "de la liste des correspondances d'extension de fichier par défaut.\n"
              "\n"
              "Si laissée vide, les modèles suivants sont testes:*.c, *.cc, *.cxx, *.cxxm,\n"
              "*.cpp, *.cppm, *.ccm, *.c++, *.c++m, *.java, *.ii, *.ixx, *.ipp, *.i++, *.inl,\n"
              "*.idl, *.ddl, *.odl, *.h, *.hh, *.hxx, *.hpp, *.h++, *.l, *.cs, *.d, *.php,\n"
              "*.php4, *.php5, *.phtml, *.inc, *.m, *.markdown, *.md, *.mm, *.dox (to be\n"
              "provided as Doxygen C comment), *.py, *.pyw, *.f90, *.f95, *.f03, *.f08,\n"
              "*.f18, *.f, *.for, *.vhd, *.vhdl, *.ucf, *.qsfet*.ice."
          );
  doc->add(
              "RECURSIVE",
              "La balise RECURSIVE peut être utilisée pour spécifier si les sous-répertoires\n"
              "doivent être recherches pour les fichiers d'entrée également.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "EXCLUDE",
              "La balise EXCLUDE peut être utilisée pour spécifier les fichiers et/ou\n"
              "répertoires qui doivent être exclus des fichiers sources INPUT. De cette\n"
              "facon, vous pouvez facilement exclure un sous-répertoire d'une arborescence de\n"
              "répertoires dont la racine est spécifiée avec la balise INPUT.\n"
              "\n"
              "Remarquez que les chemins relatifs sont relatifs au répertoire à partir duquel\n"
              "Doxygen est exécuté."
          );
  doc->add(
              "EXCLUDE_SYMLINKS",
              "La balise EXCLUDE_SYMLINKS peut être utilisée pour sélectionner si les\n"
              "fichiers ou répertoires qui sont des liens symboliques (une fonctionnalité du\n"
              "système de fichiers Unix) sont exclus de l'entrée.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "EXCLUDE_PATTERNS",
              "Si la valeur de la balise INPUT contient des répertoires, vous pouvez utiliser\n"
              "la balise EXCLUDE_PATTERNS pour spécifier un ou plusieurs modèles de\n"
              "caractères generiques pour exclure certains fichiers de ces répertoires.\n"
              "\n"
              "Notez que les caractères generiques sont comparés au fichier avec le chemin\n"
              "absolu, donc pour exclure tous les répertoires de test par exemple utilisez le\n"
              "modèle */test/*"
          );
  doc->add(
              "EXCLUDE_SYMBOLS",
              "La balise EXCLUDE_SYMBOLS peut être utilisée pour spécifier un ou plusieurs\n"
              "noms de symboles (namespaces, classes, fonctions, etc.) qui doivent être\n"
              "exclus de la sortie. Le nom de symbole peut être un nom complètement qualifie,\n"
              "un mot, ou si le caractère generique * est utilisé, une sous-chaîne. Exemples:\n"
              "ANamespace, AClass, ANamespace::AClass, ANamespace::*Test"
          );
  doc->add(
              "EXAMPLE_PATH",
              "La balise EXAMPLE_PATH peut être utilisée pour spécifier un ou plusieurs\n"
              "fichiers ou répertoires qui contiennent des fragments de code exemple qui sont\n"
              "inclus (voir la commande \\include)."
          );
  doc->add(
              "EXAMPLE_PATTERNS",
              "Si la valeur de la balise EXAMPLE_PATH contient des répertoires, vous pouvez\n"
              "utiliser la balise EXAMPLE_PATTERNS pour spécifier un ou plusieurs modèles de\n"
              "caractères generiques (comme *.cpp et *.h) pour filtrer les fichiers sources\n"
              "dans les répertoires. Si laissée vide, tous les fichiers sont inclus."
          );
  doc->add(
              "EXAMPLE_RECURSIVE",
              "Si la balise EXAMPLE_RECURSIVE est définie à YES alors les sous-répertoires\n"
              "seront recherches pour les fichiers d'entrée a utiliser avec les commandes\n"
              "\\include ou \\dontinclude indépendamment de la valeur de la balise RECURSIVE.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "IMAGE_PATH",
              "La balise IMAGE_PATH peut être utilisée pour spécifier un ou plusieurs\n"
              "fichiers ou répertoires qui contiennent des images qui doivent être incluses\n"
              "dans la documentation (voir la commande \\image)."
          );
  doc->add(
              "INPUT_FILTER",
              "La balise INPUT_FILTER peut être utilisée pour spécifier un programme que\n"
              "Doxygen devrait invoquer pour filtrer chaque fichier d'entrée. Doxygen\n"
              "invoquera le programme de filtre en executant (via popen()) la commande:\n"
              "\n"
              "<filtre> <fichier-entrée>\n"
              "\n"
              "ou <filtre> est la valeur de la balise INPUT_FILTER, et <fichier-entrée> est\n"
              "le nom d'un fichier d'entrée. Doxygen utilisera ensuite la sortie que le\n"
              "programme de filtre écrit sur la sortie standard. Si FILTER_PATTERNS est\n"
              "spécifié, cette balise sera ignorée.\n"
              "\n"
              "Notez que le filtre ne doit pas ajouter ou supprimer de lignes; il est\n"
              "appliqué avant que le code ne soit scanne, mais pas lorsque le code de sortie\n"
              "est généré. Si des lignes sont ajoutées ou supprimées, les ancres ne seront\n"
              "pas placées correctement.\n"
              "\n"
              "Notez que Doxygen utilisera les données traitées et ecrites sur la sortie\n"
              "standard pour un traitement ulterieur, donc rien d'autre, comme des\n"
              "instructions de débogage ou des commandes utilisées (donc dans le cas d'un\n"
              "fichier batch Windows utilisez toujours @echo OFF), ne doit être écrit sur la\n"
              "sortie standard.\n"
              "\n"
              "Notez que pour les extensions personnalisées ou non directement supportées\n"
              "vous devez également définir EXTENSION_MAPPING pour l'extension sinon les\n"
              "fichiers ne sont pas correctement traités par Doxygen.\n"
              ""
          );
  doc->add(
              "FILTER_PATTERNS",
              "La balise FILTER_PATTERNS peut être utilisée pour spécifier des filtres sur\n"
              "une base par modèle de fichier. Doxygen comparera le nom du fichier avec\n"
              "chaque modèle et appliquera le filtre s'il y a une correspondance. Les filtres\n"
              "sont une liste de la forme: modèle=filtre (comme *.cpp=my_cpp_filter). Voir\n"
              "INPUT_FILTER pour plus d'informations sur l'utilisation des filtres. Si la\n"
              "balise FILTER_PATTERNS est vide ou si aucun des modèles ne correspond au nom\n"
              "du fichier, INPUT_FILTER est appliqué.\n"
              "\n"
              "Notez que pour les extensions personnalisées ou non directement supportées\n"
              "vous devez également définir EXTENSION_MAPPING pour l'extension sinon les\n"
              "fichiers ne sont pas correctement traités par Doxygen.\n"
              ""
          );
  doc->add(
              "FILTER_SOURCE_FILES",
              "Si la balise FILTER_SOURCE_FILES est définie à YES, le filtre d'entrée (si\n"
              "défini en utilisant INPUT_FILTER) sera également utilisé pour filtrer les\n"
              "fichiers d'entrée qui sont utilisés pour produire les fichiers sources a\n"
              "parcourir (c'est-à-dire lorsque SOURCE_BROWSER est défini à YES).\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "FILTER_SOURCE_PATTERNS",
              "La balise FILTER_SOURCE_PATTERNS peut être utilisée pour spécifier des filtres\n"
              "sources par modèle de fichier. Un modèle remplacera le paramètre pour\n"
              "FILTER_PATTERN (s'il y en a) et il est également possible de désactiver le\n"
              "filtrage source pour un modèle spécifique en utilisant *.ext= (donc sans\n"
              "nommer de filtre).\n"
              "Cette balise nécessite que la balise FILTER_SOURCE_FILES soit définie sur YES."
          );
  doc->add(
              "USE_MDFILE_AS_MAINPAGE",
              "Si la balise USE_MDFILE_AS_MAINPAGE fait référence au nom d'un fichier\n"
              "markdown qui fait partie de l'entrée, son contenu sera place sur la page\n"
              "principale (index.html). Cela peut être utile si vous avez un projet par\n"
              "exemple sur GitHub et voulez reutiliser la page d'introduction également pour\n"
              "la sortie Doxygen."
          );
  doc->add(
              "IMPLICIT_DIR_DOCS",
              "Si la balise IMPLICIT_DIR_DOCS est définie à YES, tout fichier README.md\n"
              "trouve dans les sous-répertoires de la racine du projet est utilisé comme\n"
              "documentation pour ce sous-répertoire, sauf si le README.md commence par une\n"
              "commande \\dir, \\page ou \\mainpage. Si défini à NO, le fichier README.md doit\n"
              "commencer par une commande \\dir explicite pour être utilisé comme\n"
              "documentation de répertoire.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "FORTRAN_COMMENT_AFTER",
              "La norme Fortran spécifie que pour le code Fortran format fixe, tous les\n"
              "caractères à partir de la position 72 sont considérés comme des commentaires.\n"
              "Une extension courante est d'autoriser des lignes plus longues avant que le\n"
              "commentaire automatique ne commence. Le paramètre FORTRAN_COMMENT_AFTER\n"
              "permettra également que des lignes plus longues puissent être traitées avant\n"
              "que le commentaire automatique ne commence.\n"
              "Valeur minimum : 7, valeur maximum : 10000, valeur par défaut : 72."
          );
  doc->add(
              "SOURCE_BROWSER",
              "Si la balise SOURCE_BROWSER est définie à YES, une liste de fichiers sources\n"
              "sera générée. Les entités documentées seront référencées croisées avec ces\n"
              "sources.\n"
              "\n"
              "Remarque: Pour se débarrasser de tout le code source dans la sortie générée,\n"
              "assurez-vous que également VERBATIM_HEADERS est défini à NO.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "INLINE_SOURCES",
              "Définir la balise INLINE_SOURCES à YES inclura le corps des fonctions, macros\n"
              "multilignes, énumérations ou variables a initialisation de liste directement\n"
              "dans la documentation.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "STRIP_CODE_COMMENTS",
              "Définir la balise STRIP_CODE_COMMENTS à YES indiquera a Doxygen de cacher tous\n"
              "les blocs de commentaires speciaux des fragments de code source générés. Les\n"
              "commentaires normaux C, C++ et Fortran resteront toujours visibles.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "REFERENCED_BY_RELATION",
              "Si la balise REFERENCED_BY_RELATION est définie à YES, alors pour chaque\n"
              "entité documentée, toutes les fonctions documentées la referencant seront\n"
              "listées.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "REFERENCES_RELATION",
              "Si la balise REFERENCES_RELATION est définie à YES, alors pour chaque fonction\n"
              "documentée, toutes les entités documentées appelées/utilisées par cette\n"
              "fonction seront listées.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "REFERENCES_LINK_SOURCE",
              "Si la balise REFERENCES_LINK_SOURCE est définie à YES et que la balise\n"
              "SOURCE_BROWSER est définie à YES, alors les hyperliens des fonctions dans les\n"
              "listes REFERENCES_RELATION et REFERENCED_BY_RELATION pointeront vers le code\n"
              "source. Sinon, ils pointeront vers la documentation.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "SOURCE_TOOLTIPS",
              "Si SOURCE_TOOLTIPS est activé (le défaut), alors survoler un hyperlien dans le\n"
              "code source affichera une infobulle avec des informations supplémentaires\n"
              "telles que le prototype, la description brève et les liens vers la définition\n"
              "et la documentation. Comme cela rendra le fichier HTML plus grand et le\n"
              "chargement des grands fichiers un peu plus lent, vous pouvez choisir de\n"
              "désactiver cette fonctionnalité.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise SOURCE_BROWSER soit définie sur YES."
          );
  doc->add(
              "USE_HTAGS",
              "Si la balise USE_HTAGS est définie à YES, les références au code source\n"
              "pointeront vers le HTML généré par l'outil htags(1) au lieu du navigateur de\n"
              "source intégré de Doxygen. L'outil htags fait partie du système de balisage de\n"
              "source global de GNU (voir https://www.gnu.org/software/global/global.html).\n"
              "Vous aurez besoin de la version 4.8.6 ou supérieure.\n"
              "\n"
              "Pour l'utiliser, faites ce qui suit:\n"
              "- Installez la dernière version de global\n"
              "- Activez SOURCE_BROWSER et USE_HTAGS dans le fichier de configuration\n"
              "- Assurez-vous que INPUT pointe vers la racine de l'arborescence des sources\n"
              "- Exécutez doxygen normalement\n"
              "\n"
              "Doxygen invoquera htags (et qui invoquera à son tour gtags), donc ces outils\n"
              "doivent être disponibles depuis la ligne de commande (c'est-à-dire dans le\n"
              "chemin de recherche).\n"
              "\n"
              "Résultat: au lieu du navigateur de source généré par Doxygen, les liens vers\n"
              "le code source pointeront maintenant vers la sortie de htags.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise SOURCE_BROWSER soit définie sur YES."
          );
  doc->add(
              "VERBATIM_HEADERS",
              "Si la balise VERBATIM_HEADERS est définie à YES, Doxygen générera une copie\n"
              "verbatim du fichier d'en-tête pour chaque classe pour laquelle une inclusion\n"
              "est spécifiée. Définir à NO pour désactiver cela.\n"
              "Voir aussi : Section \\class.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "CLANG_ASSISTED_PARSING",
              "Si la balise CLANG_ASSISTED_PARSING est définie à YES, Doxygen utilisera\n"
              "l'analyseur clang (see:\n"
              "http://clang.llvm.org/) pour une analyse plus précise au prix de performances\n"
              "reduites. Cela peut être particulièrement utile avec le code C++ riche en\n"
              "templates pour lequel l'analyseur intégré de Doxygen manque des informations\n"
              "de type nécessaires.\n"
              "Note : La disponibilité de cette option dépend de si Doxygen a été généré avec\n"
              "l'option -Duse_libclang=ON pour CMake.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "CLANG_ADD_INC_PATHS",
              "Si la balise CLANG_ASSISTED_PARSING est définie à YES et que la balise\n"
              "CLANG_ADD_INC_PATHS est définie à YES, Doxygen ajoutera le répertoire de\n"
              "chaque entrée au chemin d'inclusion.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise CLANG_ASSISTED_PARSING soit définie sur\n"
              "YES."
          );
  doc->add(
              "CLANG_OPTIONS",
              "Si l'analyse assistée par clang est activée, vous pouvez fournir au\n"
              "compilateur des options de ligne de commande que vous utiliseriez normalement\n"
              "lors de l'appel du compilateur. Remarquez que les chemins d'inclusion seront\n"
              "déjà définis par Doxygen pour les fichiers et répertoires spécifiés avec INPUT\n"
              "et INCLUDE_PATH.\n"
              "Cette balise nécessite que la balise CLANG_ASSISTED_PARSING soit définie sur\n"
              "YES."
          );
  doc->add(
              "CLANG_DATABASE_PATH",
              "Si l'analyse assistée par clang est activée, vous pouvez fournir à l'analyseur\n"
              "clang le chemin vers le répertoire contenant un fichier appelé\n"
              "compile_commands.json. Ce fichier est la base de données de compilation (see:\n"
              "http://clang.llvm.org/docs/HowToSetupToolingForLLVM.html) contenant les\n"
              "options utilisées lors de la construction des fichiers sources. Cela équivaut\n"
              "a spécifier l'option -p à un outil clang, tel que clang-check. Ces options\n"
              "seront ensuite passées à l'analyseur. Toutes les options spécifiées avec\n"
              "CLANG_OPTIONS seront également ajoutées.\n"
              "Note : La disponibilité de cette option dépend de si Doxygen a été généré avec\n"
              "l'option -Duse_libclang=ON pour CMake."
          );
  doc->add(
              "ALPHABETICAL_INDEX",
              "Si la balise ALPHABETICAL_INDEX est définie à YES, un index alphabetique de\n"
              "tous les composes sera généré. Activez cela si le projet contient beaucoup de\n"
              "classes, structures, unions ou interfaces.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "IGNORE_PREFIX",
              "La balise IGNORE_PREFIX peut être utilisée pour spécifier un préfixe (ou une\n"
              "liste de préfixes) qui doit être ignore lors de la génération des en-têtes\n"
              "d'index. La balise IGNORE_PREFIX fonctionne pour les noms de classes,\n"
              "fonctions et membres. L'entité sera placée dans la liste alphabetique sous la\n"
              "première lettre du nom de l'entité qui reste après suppression du préfixe.\n"
              "Cette balise nécessite que la balise ALPHABETICAL_INDEX soit définie sur YES."
          );
  doc->add(
              "GENERATE_HTML",
              "Si la balise GENERATE_HTML est définie à YES, Doxygen générera une sortie HTML\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "HTML_OUTPUT",
              "La balise HTML_OUTPUT est utilisée pour spécifier ou les docs HTML seront\n"
              "placées. Si un chemin relatif est entre, la valeur de OUTPUT_DIRECTORY sera\n"
              "mise devant.\n"
              "Le répertoire par défaut est : html.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_FILE_EXTENSION",
              "La balise HTML_FILE_EXTENSION peut être utilisée pour spécifier l'extension de\n"
              "fichier pour chaque page HTML générée (par exemple: .htm, .php, .asp).\n"
              "La valeur par défaut est : .html.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_HEADER",
              "La balise HTML_HEADER peut être utilisée pour spécifier un fichier d'en-tête\n"
              "HTML défini par l'utilisateur pour chaque page HTML générée. Si la balise est\n"
              "laissée vide, Doxygen générera un en-tête standard.\n"
              "\n"
              "Pour obtenir un HTML valide, le fichier d'en-tête doit inclure tous les\n"
              "scripts et feuilles de style dont Doxygen a besoin, ce qui dépend des options\n"
              "de configuration utilisées (par exemple le paramètre GENERATE_TREEVIEW). Il\n"
              "est fortement recommandé de commencer avec un en-tête par défaut en utilisant\n"
              "doxygen -w html new_header.html new_footer.html new_stylesheet.css\n"
              "YourConfigFile\n"
              "puis de modifier le fichier new_header.html. Voir aussi la section \"Doxygen\n"
              "usage\" pour plus d'informations sur la génération de l'en-tête par défaut que\n"
              "Doxygen utilise normalement.\n"
              "Note : L'en-tête est sujet à changement, donc vous devez généralement\n"
              "régénérer l'en-tête par défaut lors de la mise à jour vers une version plus\n"
              "récente de Doxygen.Pour une description des marqueurs et noms de blocs\n"
              "possibles, consultez la documentation.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_FOOTER",
              "La balise HTML_FOOTER peut être utilisée pour spécifier un pied de page HTML\n"
              "défini par l'utilisateur pour chaque page HTML générée. Si la balise est\n"
              "laissée vide, Doxygen générera un pied de page standard. Voir HTML_HEADER pour\n"
              "plus d'informations sur la génération d'un pied de page par défaut et les\n"
              "commandes spéciales qui peuvent être utilisées dans le pied de page. Voir\n"
              "aussi la section \"Doxygen usage\" pour plus d'informations sur la génération du\n"
              "pied de page par défaut que Doxygen utilise normalement.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_STYLESHEET",
              "La balise HTML_STYLESHEET peut être utilisée pour spécifier une feuille de\n"
              "style en cascade définie par l'utilisateur qui est utilisée par chaque page\n"
              "HTML. Elle peut être utilisée pour affiner l'apparence de la sortie HTML. Si\n"
              "laissée vide, Doxygen générera une feuille de style par défaut. Voir aussi la\n"
              "section \"Doxygen usage\" pour plus d'informations sur la génération de la\n"
              "feuille de style que Doxygen utilise normalement.\n"
              "Note : Il est recommandé d'utiliser HTML_EXTRA_STYLESHEET au lieu de cette\n"
              "balise, car elle est plus robuste et cette balise (HTML_STYLESHEET) deviendra\n"
              "obsolète à l'avenir.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_EXTRA_STYLESHEET",
              "La balise HTML_EXTRA_STYLESHEET peut être utilisée pour spécifier des feuilles\n"
              "de style en cascade supplémentaires définies par l'utilisateur qui sont\n"
              "incluses après les feuilles de style standard créées par Doxygen. En utilisant\n"
              "cette option, on peut redéfinir certains aspects de style. Ceci est préférable\n"
              "à l'utilisation de HTML_STYLESHEET car elle ne remplace pas la feuille de\n"
              "style standard et est donc plus robuste face aux mises à jour futures. Doxygen\n"
              "copiera les fichiers de feuille de style dans le répertoire de sortie.\n"
              "Note : L'ordre des fichiers de feuille de style supplémentaires est important\n"
              "(par exemple, la dernière feuille de style de la liste redéfinit les\n"
              "paramètres des précédentes dans la liste).\n"
              "Note : Comme le style des barres de défilement ne peut actuellement pas être\n"
              "remplace dans Webkit/Chromium, le style sera omis du doxygen.css par défaut si\n"
              "une ou plusieurs feuilles de style supplémentaires ont été spécifiées. Donc si\n"
              "la personnalisation des barres de défilement est souhaitée, elle doit être\n"
              "ajoutée explicitement.Pour un exemple, consultez la documentation.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_EXTRA_FILES",
              "La balise HTML_EXTRA_FILES peut être utilisée pour spécifier un ou plusieurs\n"
              "fichiers images supplémentaires ou autres fichiers sources qui doivent être\n"
              "copiés dans le répertoire de sortie HTML. Notez que ces fichiers seront copiés\n"
              "dans le répertoire de sortie HTML de base. Utilisez le marqueur $relpath^ dans\n"
              "les fichiers HTML_HEADER et/ou HTML_FOOTER pour charger ces fichiers. Dans le\n"
              "fichier HTML_STYLESHEET, utilisez uniquement le nom du fichier. Notez\n"
              "également que les fichiers seront copiés tels quels; il n'y a pas de commandes\n"
              "ou de marqueurs disponibles.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_COLORSTYLE",
              "La balise HTML_COLORSTYLE peut être utilisée pour spécifier si la sortie HTML\n"
              "générée doit être rendue avec un thème sombre ou clair.\n"
              "Les valeurs possibles sont :LIGHT génère toujours une sortie en mode clair,\n"
              "DARK génère toujours une sortie en mode sombre, AUTO_LIGHT définit\n"
              "automatiquement le mode selon la preference de l'utilisateur, utilise le mode\n"
              "clair si aucune preference n'est définie (par défaut), AUTO_DARK définit\n"
              "automatiquement le mode selon la preference de l'utilisateur, utilise le mode\n"
              "sombre si aucune preference n'est définieetTOGGLE permet à l'utilisateur de\n"
              "basculer entre le mode clair et sombre via un bouton.\n"
              "La valeur par défaut est : AUTO_LIGHT.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_COLORSTYLE_HUE",
              "La balise HTML_COLORSTYLE_HUE contrôle la couleur de la sortie HTML. Doxygen\n"
              "ajustera les couleurs dans la feuille de style et les images d'arrière-plan en\n"
              "fonction de cette couleur. La teinte est spécifiée comme un angle sur une roue\n"
              "chromatique, voir https://en.wikipedia.org/wiki/Hue pour plus d'informations.\n"
              "Par exemple, la valeur 0 représente le rouge, 60 le jaune, 120 le vert, 180 le\n"
              "cyan, 240 le bleu, 300 le violet et 360 le rouge à nouveau.\n"
              "Valeur minimum : 0, valeur maximum : 359, valeur par défaut : 220.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_COLORSTYLE_SAT",
              "La balise HTML_COLORSTYLE_SAT contrôle la pureté (ou saturation) des couleurs\n"
              "dans la sortie HTML. Pour une valeur de 0, la sortie utilisera uniquement des\n"
              "niveaux de gris. Une valeur de 255 produira les couleurs les plus vives.\n"
              "Valeur minimum : 0, valeur maximum : 255, valeur par défaut : 100.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_COLORSTYLE_GAMMA",
              "La balise HTML_COLORSTYLE_GAMMA contrôle la correction gamma appliquée à la\n"
              "composante de luminance des couleurs dans la sortie HTML. Les valeurs\n"
              "inférieures à 100 rendent progressivement la sortie plus claire, tandis que\n"
              "les valeurs supérieures à 100 rendent la sortie plus foncée. La valeur divisée\n"
              "par 100 est le gamma réel appliqué, donc 80 représente un gamma de 0.8, la\n"
              "valeur 220 représente un gamma de 2.2, et 100 ne change pas le gamma.\n"
              "Valeur minimum : 40, valeur maximum : 240, valeur par défaut : 80.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_DYNAMIC_MENUS",
              "Si la balise HTML_DYNAMIC_MENUS est définie à YES, la documentation HTML\n"
              "générée contiendra un index principal avec des menus de navigation verticaux\n"
              "qui sont créés dynamiquement via JavaScript. Si désactivé, l'index de\n"
              "navigation consistera en plusieurs niveaux d'onglets qui sont intégrés\n"
              "statiquement dans chaque page HTML. Désactivez cette option pour prendre en\n"
              "charge les navigateurs qui n'ont pas JavaScript, comme le navigateur d'aide\n"
              "Qt.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_DYNAMIC_SECTIONS",
              "Si la balise HTML_DYNAMIC_SECTIONS est définie à YES, la documentation HTML\n"
              "générée contiendra des sections qui peuvent être cachées et affichées après le\n"
              "chargement de la page.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_CODE_FOLDING",
              "Si la balise HTML_CODE_FOLDING est définie à YES, les classes et fonctions\n"
              "peuvent être repliées et développées dynamiquement dans le code source HTML\n"
              "généré.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_COPY_CLIPBOARD",
              "Si la balise HTML_COPY_CLIPBOARD est définie à YES, Doxygen affichera une\n"
              "icône dans le coin supérieur droit des fragments de code et de texte qui\n"
              "permet à l'utilisateur de copier son contenu dans le presse-papiers. Notez que\n"
              "cela ne fonctionne que si le navigateur le prend en charge et que la page Web\n"
              "est servie via un contexte sécurisé (see:\n"
              "https://www.w3.org/TR/secure-contexts/), c'est-à-dire en utilisant le\n"
              "protocole https: ou file:.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_PROJECT_COOKIE",
              "Doxygen stocke quelques paramètres de manière persistante dans le navigateur\n"
              "(via par exemple les cookies). Par défaut, ces paramètres s'appliquent a\n"
              "toutes les pages HTML générées par Doxygen pour tous les projets. La balise\n"
              "HTML_PROJECT_COOKIE peut être utilisée pour stocker les paramètres sous une\n"
              "cle spécifique au projet, de sorte que les preferences de l'utilisateur seront\n"
              "stockées séparément.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_INDEX_NUM_ENTRIES",
              "Avec HTML_INDEX_NUM_ENTRIES, on peut contrôler le nombre préféré d'entrées\n"
              "affichées initialement dans les différents indices structures en arborescence;\n"
              "l'utilisateur peut développer et réduire les entrées dynamiquement plus tard.\n"
              "Doxygen développera l'arbre à un tel niveau qu'au maximum le nombre spécifie\n"
              "d'entrées sont visibles (sauf si un arbre complètement réduit dépasse déjà ce\n"
              "montant). Donc définir le nombre d'entrées à 1 produira un arbre complètement\n"
              "réduit par défaut. 0 est une valeur spéciale représentant un nombre infini\n"
              "d'entrées et résultera en un arbre complètement développé par défaut.\n"
              "Valeur minimum : 0, valeur maximum : 9999, valeur par défaut : 100.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "GENERATE_DOCSET",
              "Si la balise GENERATE_DOCSET est définie à YES, des fichiers d'index\n"
              "supplémentaires seront générés qui peuvent être utilisés comme entrée pour\n"
              "l'environnement de développement intégré Xcode 3 d'Apple (see:\n"
              "https://developer.apple.com/xcode/), introduit avec OSX 10.5 (Leopard). Pour\n"
              "créer un ensemble de documentation, Doxygen générera un Makefile dans le\n"
              "répertoire de sortie HTML. L'exécution de make produira le docset dans ce\n"
              "répertoire et l'exécution de make install installera le docset dans\n"
              "~/Library/Developer/Shared/Documentation/DocSets afin que Xcode le trouve au\n"
              "démarrage. Voir https://developer.apple.com/library/archive/featuredarticles/D\n"
              "oxygenXcode/_index.html pour plus d'informations.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "DOCSET_FEEDNAME",
              "Cette balise détermine le nom du flux docset. Un flux de documentation fournit\n"
              "un parapluie sous lequel plusieurs ensembles de documentation d'un seul\n"
              "fournisseur (comme une entreprise ou une suite de produits) peuvent être\n"
              "regroupes.\n"
              "La valeur par défaut est : Doxygen generated docs.\n"
              "Cette balise nécessite que la balise GENERATE_DOCSET soit définie sur YES."
          );
  doc->add(
              "DOCSET_FEEDURL",
              "Cette balise détermine l'URL du flux docset. Un flux de documentation fournit\n"
              "un parapluie sous lequel plusieurs ensembles de documentation d'un seul\n"
              "fournisseur (comme une entreprise ou une suite de produits) peuvent être\n"
              "regroupes.\n"
              "Cette balise nécessite que la balise GENERATE_DOCSET soit définie sur YES."
          );
  doc->add(
              "DOCSET_BUNDLE_ID",
              "Cette balise spécifie une chaîne qui doit identifier de manière unique\n"
              "l'ensemble de documentation bundle. Il doit s'agir d'une chaîne de style nom\n"
              "de domaine inverse, par exemple com.mycompany.MyDocSet. Doxygen ajoutera\n"
              ".docset au nom.\n"
              "La valeur par défaut est : org.doxygen.Project.\n"
              "Cette balise nécessite que la balise GENERATE_DOCSET soit définie sur YES."
          );
  doc->add(
              "DOCSET_PUBLISHER_ID",
              "La balise DOCSET_PUBLISHER_ID spécifie une chaîne qui doit identifier de\n"
              "manière unique l'editeur de la documentation. Il doit s'agir d'une chaîne de\n"
              "style nom de domaine inverse, par exemple\n"
              "com.mycompany.MyDocSet.documentation.\n"
              "La valeur par défaut est : org.doxygen.Publisher.\n"
              "Cette balise nécessite que la balise GENERATE_DOCSET soit définie sur YES."
          );
  doc->add(
              "DOCSET_PUBLISHER_NAME",
              "La balise DOCSET_PUBLISHER_NAME identifie l'editeur de la documentation.\n"
              "La valeur par défaut est : Publisher.\n"
              "Cette balise nécessite que la balise GENERATE_DOCSET soit définie sur YES."
          );
  doc->add(
              "GENERATE_HTMLHELP",
              "Si la balise GENERATE_HTMLHELP est définie à YES, Doxygen génère trois\n"
              "fichiers d'index HTML supplémentaires: index.hhp, index.hhc, et index.hhk. Le\n"
              "index.hhp est un fichier de projet qui peut être lu par l'atelier d'aide HTML\n"
              "de Microsoft sur Windows. Au début de 2021, Microsoft a mis hors ligne la page\n"
              "originale, avec notamment les liens de téléchargement (l'atelier d'aide HTML\n"
              "était déjà en mode maintenance depuis de nombreuses années). Vous pouvez\n"
              "télécharger l'atelier d'aide HTML depuis les archives Web a exécutable\n"
              "d'installation (see:\n"
              "http://web.archive.org/web/20160201063255/https://download.microsoft.com/downl\n"
              "oad/0/A/9/0A939EF6-E31C-430F-A3DF-DFAE7960D564/htmlhelp.exe).\n"
              "\n"
              "L'atelier d'aide HTML contient un compilateur qui peut convertir toute la\n"
              "sortie HTML générée par Doxygen en un seul fichier HTML compilé (.chm). Les\n"
              "fichiers HTML compilés sont maintenant utilisés comme format d'aide Windows 98\n"
              "et remplaceront l'ancien format d'aide Windows (.hlp) sur toutes les\n"
              "plateformes Windows à l'avenir. Les fichiers HTML compressés contiennent\n"
              "également un index, une table des matières, et vous pouvez rechercher des mots\n"
              "dans la documentation. L'atelier HTML contient également une visionneuse pour\n"
              "les fichiers HTML compressés.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "CHM_FILE",
              "La balise CHM_FILE peut être utilisée pour spécifier le nom du fichier .chm\n"
              "résultant. Vous pouvez ajouter un chemin devant le fichier si le résultat ne\n"
              "doit pas être écrit dans le répertoire de sortie html.\n"
              "Cette balise nécessite que la balise GENERATE_HTMLHELP soit définie sur YES."
          );
  doc->add(
              "HHC_LOCATION",
              "La balise HHC_LOCATION peut être utilisée pour spécifier l'emplacement (chemin\n"
              "absolu incluant le nom de fichier) du compilateur d'aide HTML (hhc.exe). Si\n"
              "non vide, Doxygen essaiera d'exécuter le compilateur d'aide HTML sur le\n"
              "index.hhp généré.\n"
              "Le fichier doit être spécifié avec un chemin complet.\n"
              "Cette balise nécessite que la balise GENERATE_HTMLHELP soit définie sur YES."
          );
  doc->add(
              "GENERATE_CHI",
              "Le drapeau GENERATE_CHI contrôle si un fichier d'index .chi séparé est généré\n"
              "(YES) ou s'il doit être inclus dans le fichier .chm principal (NO).\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_HTMLHELP soit définie sur YES."
          );
  doc->add(
              "CHM_INDEX_ENCODING",
              "Le CHM_INDEX_ENCODING est utilisé pour encoder le contenu du fichier d'index\n"
              "HtmlHelp (hhk), de la table des matières (hhc) et du fichier de projet.\n"
              "Cette balise nécessite que la balise GENERATE_HTMLHELP soit définie sur YES."
          );
  doc->add(
              "BINARY_TOC",
              "Le drapeau BINARY_TOC contrôle si une table des matières binaire est générée\n"
              "(YES) ou une table des matières normale (NO) dans le fichier .chm. De plus, il\n"
              "active les boutons Précédent et Suivant.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_HTMLHELP soit définie sur YES."
          );
  doc->add(
              "TOC_EXPAND",
              "Le drapeau TOC_EXPAND peut être défini à YES pour ajouter des éléments\n"
              "supplémentaires pour les membres de groupe à la table des matières de la\n"
              "documentation d'aide HTML et à la vue en arborescence.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_HTMLHELP soit définie sur YES."
          );
  doc->add(
              "SITEMAP_URL",
              "La balise SITEMAP_URL est utilisée pour spécifier l'URL complète de l'endroit\n"
              "ou la documentation générée sera placée sur le serveur par l'utilisateur lors\n"
              "du déploiement de la documentation. Le plan de site généré s'appelle\n"
              "sitemap.xml et est place dans le répertoire spécifie par HTML_OUTPUT. Si aucun\n"
              "SITEMAP_URL n'est spécifié, aucun plan de site n'est généré. Pour plus\n"
              "d'informations sur le protocole de plan de site, voir https://www.sitemaps.org\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "GENERATE_QHP",
              "Si la balise GENERATE_QHP est définie à YES et que QHP_NAMESPACE et\n"
              "QHP_VIRTUAL_FOLDER sont tous deux définis, un fichier d'index supplémentaire\n"
              "sera généré qui peut être utilisé comme entrée pour le qhelpgenerator de Qt\n"
              "pour générer une aide compressée Qt (.qch) de la documentation HTML générée.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "QCH_FILE",
              "Si la balise QHG_LOCATION est spécifiée, la balise QCH_FILE peut être utilisée\n"
              "pour spécifier le nom du fichier .qch résultant. Le chemin spécifie est\n"
              "relatif au dossier de sortie HTML.\n"
              "Cette balise nécessite que la balise GENERATE_QHP soit définie sur YES."
          );
  doc->add(
              "QHP_NAMESPACE",
              "La balise QHP_NAMESPACE spécifie l'espace de noms a utiliser lors de la\n"
              "génération de la sortie du projet d'aide Qt. Pour plus d'informations, voir\n"
              "Projet d'aide Qt / Namespace (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#namespace).\n"
              "La valeur par défaut est : org.doxygen.Project.\n"
              "Cette balise nécessite que la balise GENERATE_QHP soit définie sur YES."
          );
  doc->add(
              "QHP_VIRTUAL_FOLDER",
              "La balise QHP_VIRTUAL_FOLDER spécifie l'espace de noms a utiliser lors de la\n"
              "génération de la sortie du projet d'aide Qt. Pour plus d'informations, voir\n"
              "Projet d'aide Qt / Dossiers virtuels (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#virtual-folders).\n"
              "La valeur par défaut est : doc.\n"
              "Cette balise nécessite que la balise GENERATE_QHP soit définie sur YES."
          );
  doc->add(
              "QHP_CUST_FILTER_NAME",
              "Si la balise QHP_CUST_FILTER_NAME est définie, elle spécifie le nom d'un\n"
              "filtre personnalise a ajouter. Pour plus d'informations, voir Projet d'aide Qt\n"
              "/ Filtres personnalises (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#custom-filters).\n"
              "Cette balise nécessite que la balise GENERATE_QHP soit définie sur YES."
          );
  doc->add(
              "QHP_CUST_FILTER_ATTRS",
              "La balise QHP_CUST_FILTER_ATTRS spécifie la liste des attributs du filtre\n"
              "personnalise a ajouter. Pour plus d'informations, voir Projet d'aide Qt /\n"
              "Filtres personnalises (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#custom-filters).\n"
              "Cette balise nécessite que la balise GENERATE_QHP soit définie sur YES."
          );
  doc->add(
              "QHP_SECT_FILTER_ATTRS",
              "La balise QHP_SECT_FILTER_ATTRS spécifie la liste des attributs avec lesquels\n"
              "la section de filtre de ce projet correspond. Projet d'aide Qt / Attributs de\n"
              "filtre (see:\n"
              "https://doc.qt.io/archives/qt-4.8/qthelpproject.html#filter-attributes).\n"
              "Cette balise nécessite que la balise GENERATE_QHP soit définie sur YES."
          );
  doc->add(
              "QHG_LOCATION",
              "La balise QHG_LOCATION peut être utilisée pour spécifier l'emplacement (chemin\n"
              "absolu incluant le nom de fichier) du qhelpgenerator de Qt. Si non vide,\n"
              "Doxygen essaiera d'exécuter qhelpgenerator sur le fichier .qhp généré.\n"
              "Cette balise nécessite que la balise GENERATE_QHP soit définie sur YES."
          );
  doc->add(
              "GENERATE_ECLIPSEHELP",
              "Si la balise GENERATE_ECLIPSEHELP est définie à YES, des fichiers d'index\n"
              "supplémentaires seront générés, et avec les fichiers HTML, ils forment un\n"
              "plugin d'aide Eclipse. Pour installer ce plugin et le rendre disponible sous\n"
              "le menu du contenu d'aide dans Eclipse, le contenu du répertoire contenant les\n"
              "fichiers HTML et XML doit être copie dans le répertoire des plugins d'eclipse.\n"
              "Le nom du répertoire dans le répertoire des plugins doit être le même que la\n"
              "valeur ECLIPSE_DOC_ID. Après la copie, Eclipse doit être redemarre avant que\n"
              "l'aide n'apparaisse.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "ECLIPSE_DOC_ID",
              "Un identifiant unique pour le plugin d'aide Eclipse. Lors de l'installation du\n"
              "plugin, le nom du répertoire contenant les fichiers HTML et XML doit également\n"
              "avoir ce nom. Chaque ensemble de documentation doit avoir son propre\n"
              "identifiant.\n"
              "La valeur par défaut est : org.doxygen.Project.\n"
              "Cette balise nécessite que la balise GENERATE_ECLIPSEHELP soit définie sur\n"
              "YES."
          );
  doc->add(
              "DISABLE_INDEX",
              "Si vous voulez un contrôle complet sur la mise en page des pages HTML\n"
              "générées, il peut être nécessaire de désactiver l'index et de le remplacer par\n"
              "le votre. La balise DISABLE_INDEX peut être utilisée pour activer/désactiver\n"
              "l'index condense (onglets) en haut de chaque page HTML. Une valeur de NO\n"
              "active l'index et la valeur YES le désactive. Comme les onglets de l'index\n"
              "contiennent les mêmes informations que l'arbre de navigation, vous pouvez\n"
              "définir cette option à YES si vous définissez également GENERATE_TREEVIEW à\n"
              "YES.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "GENERATE_TREEVIEW",
              "La balise GENERATE_TREEVIEW est utilisée pour spécifier si une structure\n"
              "d'index en arborescence doit être générée pour afficher des informations\n"
              "hiérarchiques. Si la valeur de la balise est définie à YES, un panneau latéral\n"
              "sera généré contenant une structure d'index en arborescence (tout comme celle\n"
              "qui est générée pour l'aide HTML). Pour que cela fonctionne, un navigateur qui\n"
              "prend en charge JavaScript, DHTML, CSS et les cadres est requis (c'est-à-dire\n"
              "tout navigateur moderne). Les utilisateurs de Windows sont probablement mieux\n"
              "lotis en utilisant la fonctionnalité d'aide HTML. Via des feuilles de style\n"
              "personnalisées (voir HTML_EXTRA_STYLESHEET), on peut affiner davantage\n"
              "l'apparence de l'index (voir \"Fine-tuning the output\"). A titre d'exemple, la\n"
              "feuille de style par défaut générée par Doxygen à un exemple qui montre\n"
              "comment placer une image à la racine de l'arbre au lieu du PROJECT_NAME. Comme\n"
              "l'arbre a fondamentalement plus d'informations détaillées que l'index des\n"
              "onglets, vous pouvez envisager de définir DISABLE_INDEX à YES lors de\n"
              "l'activation de cette option.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "PAGE_OUTLINE_PANEL",
              "Lorsque GENERATE_TREEVIEW est défini à YES, l'option PAGE_OUTLINE_PANEL\n"
              "détermine si un panneau de navigation supplémentaire est affiché sur le côté\n"
              "droit de l'écran, affichant un plan du contenu de la page principale,\n"
              "similaire à par exemple https://developer.android.com/reference. Si\n"
              "GENERATE_TREEVIEW est défini à NO, cette option n'a aucun effet.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "FULL_SIDEBAR",
              "Lorsque GENERATE_TREEVIEW est défini à YES, l'option FULL_SIDEBAR détermine si\n"
              "la barre latérale est limitée uniquement à la zone de l'arborescence (valeur\n"
              "NO) ou si elle doit s'étendre sur toute la hauteur de la fenêtre (valeur YES).\n"
              "Définir ceci à YES donne une mise en page similaire à par exemple\n"
              "https://docs.readthedocs.io avec plus d'espace pour le contenu, mais moins\n"
              "d'espace pour le logo, le titre et la description du projet. Si\n"
              "GENERATE_TREEVIEW est défini à NO, cette option n'a aucun effet.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "ENUM_VALUES_PER_LINE",
              "La balise ENUM_VALUES_PER_LINE peut être utilisée pour définir le nombre de\n"
              "valeurs d'énumération que Doxygen regroupera sur une ligne dans la\n"
              "documentation HTML générée.\n"
              "\n"
              "Notez qu'une valeur de 0 supprimera complètement les valeurs d'énumération de\n"
              "la section de vue d'ensemble.\n"
              "Valeur minimum : 0, valeur maximum : 20, valeur par défaut : 4.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "SHOW_ENUM_VALUES",
              "Lorsque la balise SHOW_ENUM_VALUES est définie, Doxygen affichera les valeurs\n"
              "d'énumération spécifiées a côté des mnémoniques d'énumération.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "TREEVIEW_WIDTH",
              "Si l'arborescence est activée (voir GENERATE_TREEVIEW), cette balise peut être\n"
              "utilisée pour définir la largeur initiale (en pixels) du cadre dans lequel\n"
              "l'arbre est affiché.\n"
              "Valeur minimum : 0, valeur maximum : 1500, valeur par défaut : 250.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "EXT_LINKS_IN_WINDOW",
              "Si l'option EXT_LINKS_IN_WINDOW est définie à YES, Doxygen ouvrira les liens\n"
              "vers des symboles externes importés via des fichiers de balises dans une\n"
              "fenêtre séparée.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "OBFUSCATE_EMAILS",
              "Si la balise OBFUSCATE_EMAILS est définie à YES, Doxygen offusquera les\n"
              "adresses email.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "HTML_FORMULA_FORMAT",
              "Si l'option HTML_FORMULA_FORMAT est définie à svg, Doxygen utilisera l'outil\n"
              "pdf2svg (voir https://github.com/dawbarton/pdf2svg) ou inkscape (voir\n"
              "https://inkscape.org) pour générer des formules en tant qu'images SVG au lieu\n"
              "de PNG pour la sortie HTML. Ces images auront généralement une meilleure\n"
              "apparence à des resolutions mises à l'echelle.\n"
              "Les valeurs possibles sont :png (par défaut)etsvg (plus joli mais nécessite\n"
              "l'outil pdf2svg ou inkscape).\n"
              "La valeur par défaut est : png.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "FORMULA_FONTSIZE",
              "Utilisez cette balise pour changer la taille de police des formules LaTeX\n"
              "incluses en tant qu'images dans la documentation HTML. Lorsque vous changez la\n"
              "taille de police après une exécution Doxygen reussie, vous devez supprimer\n"
              "manuellement toutes les images form_*.png du répertoire de sortie HTML pour\n"
              "forcer leur regeneration.\n"
              "Valeur minimum : 8, valeur maximum : 50, valeur par défaut : 10.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "FORMULA_MACROFILE",
              "Le FORMULA_MACROFILE peut contenir des commandes LaTeX \\newcommand et\n"
              "\\renewcommand pour créer de nouvelles commandes LaTeX a utiliser dans les\n"
              "formules comme blocs de construction. Voir la section \"Including formulas\"\n"
              "pour plus de détails."
          );
  doc->add(
              "USE_MATHJAX",
              "Activez l'option USE_MATHJAX pour rendre les formules LaTeX en utilisant\n"
              "MathJax (voir https://www.mathjax.org) qui utilise JavaScript côté client pour\n"
              "le rendu au lieu d'utiliser des bitmaps pre-rendus. Utilisez ceci si vous\n"
              "n'avez pas LaTeX installe ou si vous voulez que les formules soient plus\n"
              "jolies dans la sortie HTML. lorsqu'activé, vous devrez peut-être également\n"
              "installer MathJax séparément et configurer le chemin d'accès en utilisant\n"
              "l'option MATHJAX_RELPATH.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "MATHJAX_VERSION",
              "Avec MATHJAX_VERSION, il est possible de spécifier la version de MathJax a\n"
              "utiliser. Notez que les différentes versions de MathJax ont des exigences\n"
              "différentes en ce qui concerne les différents paramètres, il est donc possible\n"
              "que d'autres paramètres MathJax doivent également être modifies lors du\n"
              "passage entre les différentes versions de MathJax.\n"
              "Les valeurs possibles sont :MathJax_2, MathJax_3etMathJax_4.\n"
              "La valeur par défaut est : MathJax_2.\n"
              "Cette balise nécessite que la balise USE_MATHJAX soit définie sur YES."
          );
  doc->add(
              "MATHJAX_FORMAT",
              "Lorsque MathJax est activé, vous pouvez définir le format de sortie par défaut\n"
              "a utiliser pour la sortie MathJax. Pour plus de détails sur le format de\n"
              "sortie, voir MathJax version 2 (see:\n"
              "https://docs.mathjax.org/en/v2.7/output.html), MathJax version 3 (see:\n"
              "https://docs.mathjax.org/en/v3.2/output/index.html) et MathJax version 4 (see:\n"
              "https://docs.mathjax.org/en/v4.0/output/index.htm).\n"
              "Les valeurs possibles sont :HTML-CSS (plus lent, mais avec la meilleure\n"
              "compatibilité. C'est le nom pour MathJax version 2, pour MathJax version 3\n"
              "cela sera traduit en chtml), NativeMML (c'est-à-dire MathML. Pris en charge\n"
              "uniquement pour MathJax 2. Pour MathJax version 3, chtml sera utilisé à la\n"
              "place.), chtml (C'est le nom pour MathJax version 3, pour MathJax version 2\n"
              "cela sera traduit en HTML-CSS)etSVG.\n"
              "La valeur par défaut est : HTML-CSS.\n"
              "Cette balise nécessite que la balise USE_MATHJAX soit définie sur YES."
          );
  doc->add(
              "MATHJAX_RELPATH",
              "Lorsque MathJax est activé, vous devez spécifier l'emplacement relatif au\n"
              "répertoire de sortie HTML en utilisant l'option MATHJAX_RELPATH. Pour MathJax\n"
              "version 2, le répertoire de destination doit contenir le script MathJax.js.\n"
              "Par exemple, si le répertoire mathjax se trouve au même niveau que le\n"
              "répertoire de sortie HTML, alors MATHJAX_RELPATH doit être ../mathjax. Pour\n"
              "MathJax versions 3 et 4, le répertoire de destination doit contenir le script\n"
              "tex-<format>.js (ou <format> est chtml ou svg). La valeur par défaut pointe\n"
              "vers le Reseau de Distribution de Contenu MathJax pour que vous puissiez voir\n"
              "rapidement le résultat sans installer MathJax. Cependant, il est fortement\n"
              "recommandé d'installer une copie locale de MathJax depuis\n"
              "https://www.mathjax.org avant le déploiement. La valeur par défaut est :\n"
              "- dans le cas de MathJax version 2 : https://cdn.jsdelivr.net/npm/mathjax@2\n"
              "- dans le cas de MathJax version 3 : https://cdn.jsdelivr.net/npm/mathjax@3\n"
              "- dans le cas de MathJax version 4 : https://cdn.jsdelivr.net/npm/mathjax@4\n"
              "Cette balise nécessite que la balise USE_MATHJAX soit définie sur YES."
          );
  doc->add(
              "MATHJAX_EXTENSIONS",
              "La balise MATHJAX_EXTENSIONS peut être utilisée pour spécifier un ou plusieurs\n"
              "noms d'extension MathJax qui doivent être activés pendant le rendu MathJax.\n"
              "Par exemple pour la version 2 de MathJax (voir\n"
              "https://docs.mathjax.org/en/v2.7/tex.html):\n"
              "MATHJAX_EXTENSIONS = TeX/AMSmath TeX/AMSsymbols\n"
              "Par exemple pour la version 3 de MathJax (voir\n"
              "https://docs.mathjax.org/en/v3.2/input/tex/extensions/):\n"
              "MATHJAX_EXTENSIONS = ams\n"
              "Par exemple pour la version 4 de MathJax (voir\n"
              "https://docs.mathjax.org/en/v4.0/input/tex/extensions/):\n"
              "MATHJAX_EXTENSIONS = units\n"
              "Notez que pour la version 4 de Mathjax, quelques extensions sont déjà\n"
              "automatiquement chargées. Pour désactiver un paquet dans la version 4 de\n"
              "Mathjax, on peut utiliser le nom du paquet précède d'un signe moins (- comme\n"
              "MATHJAX_EXTENSIONS += -textmacros)\n"
              "Cette balise nécessite que la balise USE_MATHJAX soit définie sur YES."
          );
  doc->add(
              "MATHJAX_CODEFILE",
              "La balise MATHJAX_CODEFILE peut être utilisée pour spécifier un fichier avec\n"
              "des morceaux de code JavaScript qui seront utilisés au démarrage du code\n"
              "MathJax. Voir le site Mathjax pour plus de détails:\n"
              "- MathJax version 2 (see:\n"
              "https://docs.mathjax.org/en/v2.7/)\n"
              "- MathJax version 3 (see:\n"
              "https://docs.mathjax.org/en/v3.2/)\n"
              "- MathJax version 4 (see:\n"
              "https://docs.mathjax.org/en/v4.0/)Pour un exemple, consultez la documentation.\n"
              "Cette balise nécessite que la balise USE_MATHJAX soit définie sur YES."
          );
  doc->add(
              "SEARCHENGINE",
              "Lorsque la balise SEARCHENGINE est activée, Doxygen générera une boite de\n"
              "recherche pour la sortie HTML. Le moteur de recherche sous-jacent utilise\n"
              "JavaScript et DHTML et devrait fonctionner sur tout navigateur moderne. Notez\n"
              "que lors de l'utilisation de l'aide HTML (GENERATE_HTMLHELP), de l'aide Qt\n"
              "(GENERATE_QHP) ou des docsets (GENERATE_DOCSET), il existe déjà une fonction\n"
              "de recherche, celle-ci devrait donc généralement être désactivée. Pour les\n"
              "grands projets, le moteur de recherche base sur JavaScript peut être lent,\n"
              "alors l'activation de SERVER_BASED_SEARCH peut fournir une meilleure solution.\n"
              "Il est possible de rechercher en utilisant le clavier; pour accéder à la boite\n"
              "de recherche, utilisez <touche d'accès> + S (ce qu'est la <touche d'accès>\n"
              "dépend de l'OS et du navigateur, mais c'est généralement <CTRL>,\n"
              "<ALT>/<option>, ou les deux). Dans la boite de recherche, utilisez la <touche\n"
              "curseur bas> pour accéder à la fenêtre des résultats de recherche, les\n"
              "résultats peuvent être navigues en utilisant les <touches curseur>. Appuyez\n"
              "sur <Entrée> pour sélectionner un élément ou <echap> pour annuler la\n"
              "recherche. Les options de filtre peuvent être sélectionnées lorsque le curseur\n"
              "est dans la boite de recherche en appuyant sur <Maj>+<curseur bas>. Ici aussi,\n"
              "utilisez les <touches curseur> pour sélectionner un filtre et <Entrée> ou\n"
              "<echap> pour activer ou annuler l'option de filtre.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise GENERATE_HTML soit définie sur YES."
          );
  doc->add(
              "SERVER_BASED_SEARCH",
              "Lorsque la balise SERVER_BASED_SEARCH est activée, le moteur de recherche sera\n"
              "implémenté en utilisant un serveur Web au lieu d'un client Web utilisant\n"
              "JavaScript. Il existe deux types de recherche basée sur un serveur Web selon\n"
              "le paramètre EXTERNAL_SEARCH. Lorsqu'il est désactivé, Doxygen générera un\n"
              "script PHP pour la recherche et un fichier d'index utilisé par le script.\n"
              "Lorsque EXTERNAL_SEARCH est activé, l'indexation et la recherche doivent être\n"
              "fournies par des outils externes. Voir la section \"External Indexing and\n"
              "Searching\" pour plus de détails.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise SEARCHENGINE soit définie sur YES."
          );
  doc->add(
              "EXTERNAL_SEARCH",
              "Lorsque la balise EXTERNAL_SEARCH est activée, Doxygen ne générera plus le\n"
              "script PHP pour la recherche. Au lieu de cela, les résultats de recherche sont\n"
              "écrits dans un fichier XML qui doit être traite par un indexeur externe.\n"
              "Doxygen invoquera un moteur de recherche externe pointe par l'option\n"
              "SEARCHENGINE_URL pour obtenir les résultats de recherche.\n"
              "\n"
              "Doxygen est fourni avec un exemple d'indexeur (doxyindexer) et de moteur de\n"
              "recherche (doxysearch.cgi) qui sont bases sur la bibliothèque de moteur de\n"
              "recherche open source Xapian (see:\n"
              "https://xapian.org/).\n"
              "\n"
              "Voir la section \"External Indexing and Searching\" pour plus de détails.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise SEARCHENGINE soit définie sur YES."
          );
  doc->add(
              "SEARCHENGINE_URL",
              "Le SEARCHENGINE_URL doit pointer vers un moteur de recherche heberge par un\n"
              "serveur Web qui retourner les résultats de recherche lorsque EXTERNAL_SEARCH\n"
              "est activé.\n"
              "\n"
              "Doxygen est fourni avec un exemple d'indexeur (doxyindexer) et de moteur de\n"
              "recherche (doxysearch.cgi) qui sont bases sur la bibliothèque de moteur de\n"
              "recherche open source Xapian (see:\n"
              "https://xapian.org/). Voir la section \"External Indexing and Searching\" pour\n"
              "plus de détails.\n"
              "Cette balise nécessite que la balise SEARCHENGINE soit définie sur YES."
          );
  doc->add(
              "SEARCHDATA_FILE",
              "Lorsque SERVER_BASED_SEARCH et EXTERNAL_SEARCH sont tous deux activés, les\n"
              "données de recherche non indexées sont ecrites dans un fichier pour\n"
              "l'indexation par un outil externe. Avec la balise SEARCHDATA_FILE, le nom de\n"
              "ce fichier peut être spécifie.\n"
              "Le fichier par défaut est : searchdata.xml.\n"
              "Cette balise nécessite que la balise SEARCHENGINE soit définie sur YES."
          );
  doc->add(
              "EXTERNAL_SEARCH_ID",
              "Lorsque SERVER_BASED_SEARCH et EXTERNAL_SEARCH sont tous deux activés, la\n"
              "balise EXTERNAL_SEARCH_ID peut être utilisée comme identifiant pour le projet.\n"
              "Ceci est utile en combinaison avec EXTRA_SEARCH_MAPPINGS pour rechercher dans\n"
              "plusieurs projets et rediriger les résultats vers le bon projet.\n"
              "Cette balise nécessite que la balise SEARCHENGINE soit définie sur YES."
          );
  doc->add(
              "EXTRA_SEARCH_MAPPINGS",
              "La balise EXTRA_SEARCH_MAPPINGS peut être utilisée pour activer la recherche\n"
              "dans des projets Doxygen autres que celui défini par ce fichier de\n"
              "configuration, mais qui sont tous ajoutés au même index de recherche externe.\n"
              "Chaque projet doit avoir un identifiant unique défini via EXTERNAL_SEARCH_ID.\n"
              "Le mappage de recherche mappe ensuite l'identifiant vers un emplacement\n"
              "relatif ou la documentation peut être trouvée. Le format est:\n"
              "EXTRA_SEARCH_MAPPINGS = tagname1=loc1 tagname2=loc2 ...\n"
              "Cette balise nécessite que la balise SEARCHENGINE soit définie sur YES."
          );
  doc->add(
              "GENERATE_LATEX",
              "Si la balise GENERATE_LATEX est définie à YES, Doxygen générera une sortie\n"
              "LaTeX.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "LATEX_OUTPUT",
              "La balise LATEX_OUTPUT est utilisée pour spécifier ou les docs LaTeX seront\n"
              "placées. Si un chemin relatif est entre, la valeur de OUTPUT_DIRECTORY sera\n"
              "mise devant.\n"
              "Le répertoire par défaut est : latex.\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "LATEX_CMD_NAME",
              "La balise LATEX_CMD_NAME peut être utilisée pour spécifier le nom de la\n"
              "commande LaTeX a invoquer.\n"
              "\n"
              "Notez que lorsque USE_PDFLATEX n'est pas active, le défaut est latex, lorsque\n"
              "USE_PDFLATEX est activé, le défaut est pdflatex et dans ce dernier cas si\n"
              "latex est choisi, il est écrasé par pdflatex. Pour des langages de sortie\n"
              "spécifiques, le défaut peut avoir été défini différemment, cela dépend de\n"
              "l'implémentation du langage de sortie.\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "MAKEINDEX_CMD_NAME",
              "La balise MAKEINDEX_CMD_NAME peut être utilisée pour spécifier le nom de la\n"
              "commande pour générer l'index pour LaTeX.\n"
              "Note : Cette balise est utilisée dans le Makefile / make.bat.\n"
              "Voir aussi : LATEX_MAKEINDEX_CMD pour la partie dans le fichier de sortie\n"
              "généré (.tex).\n"
              "Le fichier par défaut est : makeindex.\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "LATEX_MAKEINDEX_CMD",
              "La balise LATEX_MAKEINDEX_CMD peut être utilisée pour spécifier le nom de la\n"
              "commande pour générer l'index pour LaTeX. S'il n'y a pas de barre oblique\n"
              "inverse (\\) comme premier caractère, elle sera automatiquement ajoutée dans le\n"
              "code LaTeX.\n"
              "Note : Cette balise est utilisée dans le fichier de sortie généré (.tex).\n"
              "Voir aussi : MAKEINDEX_CMD_NAME pour la partie dans le Makefile / make.bat.\n"
              "La valeur par défaut est : makeindex.\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "COMPACT_LATEX",
              "Si la balise COMPACT_LATEX est définie à YES, Doxygen génère des documents\n"
              "LaTeX plus compacts. Cela peut être utile pour les petits projets et peut\n"
              "aider a economiser quelques arbres en général.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "PAPER_TYPE",
              "La balise PAPER_TYPE peut être utilisée pour définir le type de papier utilisé\n"
              "par l'imprimante.\n"
              "Les valeurs possibles sont :a4 (210 x 297 mm), letter (8,5 x 11 pouces), legal\n"
              "(8,5 x 14 pouces)etexecutive (7,25 x 10,5 pouces).\n"
              "La valeur par défaut est : a4.\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "EXTRA_PACKAGES",
              "La balise EXTRA_PACKAGES peut être utilisée pour spécifier un ou plusieurs\n"
              "noms de paquets LaTeX qui doivent être inclus dans la sortie LaTeX. Le paquet\n"
              "peut être spécifie simplement par son nom ou avec la syntaxe correcte a\n"
              "utiliser avec la commande LaTeX \\usepackage. Pour obtenir la police times par\n"
              "exemple, vous pouvez spécifier:\n"
              "EXTRA_PACKAGES=times ou EXTRA_PACKAGES={times}\n"
              "Pour utiliser l'option intlimits avec le paquet amsmath, vous pouvez\n"
              "spécifier:\n"
              "EXTRA_PACKAGES=[intlimits]{amsmath}\n"
              "Si laissé vide, aucun paquet supplémentaire ne sera inclus.\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "LATEX_HEADER",
              "La balise LATEX_HEADER peut être utilisée pour spécifier un en-tête LaTeX\n"
              "défini par l'utilisateur pour le document LaTeX généré. L'en-tête doit\n"
              "contenir tout jusqu'au premier chapitre. S'il est laissé vide, Doxygen\n"
              "générera un en-tête standard. Il est fortement recommandé de commencer avec un\n"
              "en-tête par défaut en utilisant\n"
              "doxygen -w latex new_header.tex new_footer.tex new_stylesheet.sty\n"
              "puis de modifier le fichier new_header.tex. Voir aussi la section \"Doxygen\n"
              "usage\" pour plus d'informations sur la génération de l'en-tête par défaut que\n"
              "Doxygen utilise normalement.\n"
              "\n"
              "Note: N'utilisez un en-tête défini par l'utilisateur que si vous savez ce que\n"
              "vous faites!\n"
              "Note : L'en-tête est sujet à changement, donc vous devez généralement\n"
              "régénérer l'en-tête par défaut lors de la mise à jour vers une version plus\n"
              "récente de Doxygen.Pour une description des marqueurs et noms de blocs\n"
              "possibles, consultez la documentation.\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "LATEX_FOOTER",
              "La balise LATEX_FOOTER peut être utilisée pour spécifier un pied de page LaTeX\n"
              "défini par l'utilisateur pour le document LaTeX généré. Le pied de page doit\n"
              "contenir tout après le dernier chapitre. S'il est laissé vide, Doxygen\n"
              "générera un pied de page standard. Voir LATEX_HEADER pour plus d'informations\n"
              "sur la génération d'un pied de page par défaut et les commandes spéciales qui\n"
              "peuvent être utilisées dans le pied de page. Voir aussi la section \"Doxygen\n"
              "usage\" pour plus d'informations sur la génération du pied de page par défaut\n"
              "que Doxygen utilise normalement. Note: N'utilisez un pied de page défini par\n"
              "l'utilisateur que si vous savez ce que vous faites!\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "LATEX_EXTRA_STYLESHEET",
              "La balise LATEX_EXTRA_STYLESHEET peut être utilisée pour spécifier des\n"
              "feuilles de style LaTeX supplémentaires définies par l'utilisateur qui sont\n"
              "incluses après les feuilles de style standard créées par Doxygen. En utilisant\n"
              "cette option, on peut redéfinir certains aspects de style. Doxygen copiera les\n"
              "fichiers de feuille de style dans le répertoire de sortie.\n"
              "Note : L'ordre des fichiers de feuille de style supplémentaires est important\n"
              "(par exemple, la dernière feuille de style de la liste redéfinit les\n"
              "paramètres des précédentes dans la liste).\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "LATEX_EXTRA_FILES",
              "La balise LATEX_EXTRA_FILES peut être utilisée pour spécifier une ou plusieurs\n"
              "images supplémentaires ou autres fichiers sources qui doivent être copiés dans\n"
              "le répertoire de sortie LATEX_OUTPUT. Notez que les fichiers seront copiés\n"
              "tels quels; il n'y a pas de commandes ou de marqueurs disponibles.\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "PDF_HYPERLINKS",
              "Si la balise PDF_HYPERLINKS est définie à YES, le LaTeX généré est prepare\n"
              "pour la conversion en PDF (en utilisant ps2pdf ou pdflatex). Le fichier PDF\n"
              "contiendra des liens (tout comme la sortie HTML) au lieu de références de\n"
              "pages. Cela rend la sortie adaptée à la navigation en ligne en utilisant un\n"
              "lecteur PDF.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "USE_PDFLATEX",
              "Si la balise USE_PDFLATEX est définie à YES, Doxygen utilisera le moteur comme\n"
              "spécifie avec LATEX_CMD_NAME pour générer le fichier PDF directement à partir\n"
              "des fichiers LaTeX. Définissez cette option à YES pour obtenir une\n"
              "documentation PDF de meilleure qualité.\n"
              "\n"
              "Voir aussi la section LATEX_CMD_NAME pour sélectionner le moteur.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "LATEX_BATCHMODE",
              "La balise LATEX_BATCHMODE signale le comportement de LaTeX en cas d'erreur.\n"
              "Les valeurs possibles sont :NO identique a ERROR_STOP, YES identique a BATCH,\n"
              "BATCH En mode batch, rien n'est imprime sur le terminal, les erreurs defilent\n"
              "comme si <return> était appuye à chaque erreur; les fichiers manquants que TeX\n"
              "essaie de lire ou de demander à partir de l'entrée clavier (\\read sur un flux\n"
              "d'entrée non ouvert) provoquent l'arret du travail, NON_STOP En mode nonstop,\n"
              "le message de diagnostic apparaîtra sur le terminal, mais il n'y a aucune\n"
              "possibilite d'interaction utilisateur comme en mode batch, SCROLL En mode\n"
              "scroll, TeX s'arrêtera uniquement pour les fichiers manquants a lire ou si une\n"
              "entrée clavier est nécessaireetERROR_STOP En mode errorstop, TeX s'arrêtera à\n"
              "chaque erreur, demandant l'intervention de l'utilisateur.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "LATEX_HIDE_INDICES",
              "Si la balise LATEX_HIDE_INDICES est définie à YES, Doxygen n'inclura pas les\n"
              "chapitres d'index (tels que l'index des fichiers, l'index des composes, etc.)\n"
              "dans la sortie.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "LATEX_BIB_STYLE",
              "La balise LATEX_BIB_STYLE peut être utilisée pour spécifier le style a\n"
              "utiliser pour la bibliographie, par exemple plainnat ou ieeetr. Voir\n"
              "https://en.wikipedia.org/wiki/BibTeX et \\cite pour plus d'informations.\n"
              "La valeur par défaut est : plainnat.\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "LATEX_EMOJI_DIRECTORY",
              "La balise LATEX_EMOJI_DIRECTORY est utilisée pour spécifier le chemin (relatif\n"
              "ou absolu) à partir duquel les images emoji seront lues. Si un chemin relatif\n"
              "est entre, il sera relatif au répertoire LATEX_OUTPUT. Si laissé vide, le\n"
              "répertoire LATEX_OUTPUT sera utilisé.\n"
              "Cette balise nécessite que la balise GENERATE_LATEX soit définie sur YES."
          );
  doc->add(
              "GENERATE_RTF",
              "Si la balise GENERATE_RTF est définie à YES, Doxygen générera une sortie RTF.\n"
              "La sortie RTF est optimisée pour Word 97 et peut ne pas sembler tres jolie\n"
              "avec d'autres lecteurs/editeurs RTF.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "RTF_OUTPUT",
              "La balise RTF_OUTPUT est utilisée pour spécifier ou les docs RTF seront\n"
              "placées. Si un chemin relatif est entre, la valeur de OUTPUT_DIRECTORY sera\n"
              "mise devant.\n"
              "Le répertoire par défaut est : rtf.\n"
              "Cette balise nécessite que la balise GENERATE_RTF soit définie sur YES."
          );
  doc->add(
              "COMPACT_RTF",
              "Si la balise COMPACT_RTF est définie à YES, Doxygen génère des documents RTF\n"
              "plus compacts. Cela peut être utile pour les petits projets et peut aider a\n"
              "economiser quelques arbres en général.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_RTF soit définie sur YES."
          );
  doc->add(
              "RTF_HYPERLINKS",
              "Si la balise RTF_HYPERLINKS est définie à YES, le RTF généré contiendra des\n"
              "champs de lien hypertexte. Le fichier RTF contiendra des liens (tout comme la\n"
              "sortie HTML) au lieu de références de pages. Cela rend la sortie adaptée à la\n"
              "navigation en ligne en utilisant Word ou d'autres lecteurs compatibles Word\n"
              "qui prennent en charge ces champs.\n"
              "\n"
              "Note: WordPad (write) et d'autres ne prennent pas en charge les liens.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_RTF soit définie sur YES."
          );
  doc->add(
              "RTF_STYLESHEET_FILE",
              "Charge les définitions de feuille de style à partir d'un fichier. La syntaxe\n"
              "est similaire au fichier de configuration de Doxygen, c'est-à-dire une serie\n"
              "d'affectations. Vous devez uniquement fournir des remplacements, les\n"
              "définitions manquantes sont définies a leur valeur par défaut.\n"
              "\n"
              "Voir aussi la section \"Doxygen usage\" pour plus d'informations sur la\n"
              "génération de la feuille de style par défaut que Doxygen utilise normalement.\n"
              "Cette balise nécessite que la balise GENERATE_RTF soit définie sur YES."
          );
  doc->add(
              "RTF_EXTENSIONS_FILE",
              "Définit des variables optionnelles utilisées dans la génération d'un document\n"
              "RTF. La syntaxe est similaire au fichier de configuration de Doxygen. Un\n"
              "fichier d'extensions modèle peut être généré en utilisant doxygen -e rtf\n"
              "extensionFile.\n"
              "Cette balise nécessite que la balise GENERATE_RTF soit définie sur YES."
          );
  doc->add(
              "RTF_EXTRA_FILES",
              "La balise RTF_EXTRA_FILES peut être utilisée pour spécifier une ou plusieurs\n"
              "images supplémentaires ou autres fichiers sources qui doivent être copiés dans\n"
              "le répertoire de sortie RTF_OUTPUT. Notez que les fichiers seront copiés tels\n"
              "quels; il n'y a pas de commandes ou de marqueurs disponibles.\n"
              "Cette balise nécessite que la balise GENERATE_RTF soit définie sur YES."
          );
  doc->add(
              "GENERATE_MAN",
              "Si la balise GENERATE_MAN est définie à YES, Doxygen générera des pages de\n"
              "manuel pour les classes et les fichiers.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "MAN_OUTPUT",
              "La balise MAN_OUTPUT est utilisée pour spécifier ou les pages de manuel seront\n"
              "placées. Si un chemin relatif est entre, la valeur de OUTPUT_DIRECTORY sera\n"
              "mise devant. Un répertoire man3 sera créé dans le répertoire spécifie par\n"
              "MAN_OUTPUT.\n"
              "Le répertoire par défaut est : man.\n"
              "Cette balise nécessite que la balise GENERATE_MAN soit définie sur YES."
          );
  doc->add(
              "MAN_EXTENSION",
              "La balise MAN_EXTENSION détermine l'extension qui est ajoutée aux pages de\n"
              "manuel générées. Si la section du manuel ne commence pas par un chiffre, le\n"
              "chiffre 3 est ajouté au début. Le point (.) au début de la balise\n"
              "MAN_EXTENSION est optionnel.\n"
              "La valeur par défaut est : .3.\n"
              "Cette balise nécessite que la balise GENERATE_MAN soit définie sur YES."
          );
  doc->add(
              "MAN_SUBDIR",
              "La balise MAN_SUBDIR détermine le nom du répertoire créé dans MAN_OUTPUT dans\n"
              "lequel les pages de manuel sont placées. Par défaut, c'est man suivi de\n"
              "MAN_EXTENSION avec le . initial supprime.\n"
              "Cette balise nécessite que la balise GENERATE_MAN soit définie sur YES."
          );
  doc->add(
              "MAN_LINKS",
              "Si la balise MAN_LINKS est définie à YES et que Doxygen génère une sortie man,\n"
              "alors il générera un fichier man supplémentaire pour chaque entité documentée\n"
              "dans la ou les vraies pages de manuel. Ces fichiers supplémentaires ne font\n"
              "que sourcer la vraie page de manuel, mais sans eux la commande man serait\n"
              "incapable de trouver la bonne page.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_MAN soit définie sur YES."
          );
  doc->add(
              "GENERATE_XML",
              "Si la balise GENERATE_XML est définie à YES, Doxygen générera un fichier XML\n"
              "qui capture la structure du code, y compris toute la documentation.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "XML_OUTPUT",
              "La balise XML_OUTPUT est utilisée pour spécifier ou les pages XML seront\n"
              "placées. Si un chemin relatif est entre, la valeur de OUTPUT_DIRECTORY sera\n"
              "mise devant.\n"
              "Le répertoire par défaut est : xml.\n"
              "Cette balise nécessite que la balise GENERATE_XML soit définie sur YES."
          );
  doc->add(
              "XML_PROGRAMLISTING",
              "Si la balise XML_PROGRAMLISTING est définie à YES, Doxygen copiera les listes\n"
              "de programmes (y compris la coloration syntaxique et les informations de\n"
              "référence croisée) dans la sortie XML. Notez que l'activation de cela\n"
              "augmentera de manière significative la taille de la sortie XML.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise GENERATE_XML soit définie sur YES."
          );
  doc->add(
              "XML_NS_MEMB_FILE_SCOPE",
              "Si la balise XML_NS_MEMB_FILE_SCOPE est définie à YES, Doxygen inclura les\n"
              "membres de namespace dans la portée du fichier également, correspondant à la\n"
              "sortie HTML.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_XML soit définie sur YES."
          );
  doc->add(
              "GENERATE_DOCBOOK",
              "Si la balise GENERATE_DOCBOOK est définie à YES, Doxygen générera des fichiers\n"
              "Docbook qui peuvent être utilisés pour générer du PDF.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "DOCBOOK_OUTPUT",
              "La balise DOCBOOK_OUTPUT est utilisée pour spécifier ou les pages Docbook\n"
              "seront placées. Si un chemin relatif est entre, la valeur de OUTPUT_DIRECTORY\n"
              "sera mise devant.\n"
              "Le répertoire par défaut est : docbook.\n"
              "Cette balise nécessite que la balise GENERATE_DOCBOOK soit définie sur YES."
          );
  doc->add(
              "GENERATE_AUTOGEN_DEF",
              "Si la balise GENERATE_AUTOGEN_DEF est définie à YES, Doxygen générera un\n"
              "fichier de définitions AutoGen (voir https://autogen.sourceforge.net/) qui\n"
              "capture la structure du code, y compris toute la documentation. Notez que\n"
              "cette fonctionnalité est encore expérimentale et incomplète pour le moment.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "GENERATE_SQLITE3",
              "Si la balise GENERATE_SQLITE3 est définie à YES, Doxygen générera une base de\n"
              "données Sqlite3 avec les symboles trouvés par Doxygen stockés dans des tables.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "SQLITE3_OUTPUT",
              "La balise SQLITE3_OUTPUT est utilisée pour spécifier ou la base de données\n"
              "Sqlite3 sera placée. Si un chemin relatif est entre, la valeur de\n"
              "OUTPUT_DIRECTORY sera mise devant.\n"
              "Le répertoire par défaut est : sqlite3.\n"
              "Cette balise nécessite que la balise GENERATE_SQLITE3 soit définie sur YES."
          );
  doc->add(
              "SQLITE3_RECREATE_DB",
              "Si la balise SQLITE3_RECREATE_DB est définie à YES, le fichier de base de\n"
              "données doxygen_sqlite3.db existant sera recréé à chaque exécution de Doxygen.\n"
              "Si défini à NO, Doxygen avertira si un fichier de base de données est déjà\n"
              "trouve et ne le modifiera pas.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise GENERATE_SQLITE3 soit définie sur YES."
          );
  doc->add(
              "GENERATE_PERLMOD",
              "Si la balise GENERATE_PERLMOD est définie à YES, Doxygen générera un fichier\n"
              "de module Perl qui capture la structure du code, y compris toute la\n"
              "documentation.\n"
              "\n"
              "Notez que cette fonctionnalité est encore expérimentale et incomplète pour le\n"
              "moment.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "PERLMOD_LATEX",
              "Si la balise PERLMOD_LATEX est définie à YES, Doxygen générera les règles\n"
              "Makefile nécessaires, les scripts Perl et le code LaTeX pour pouvoir générer\n"
              "une sortie PDF et DVI à partir de la sortie du module Perl.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise GENERATE_PERLMOD soit définie sur YES."
          );
  doc->add(
              "PERLMOD_PRETTY",
              "Si la balise PERLMOD_PRETTY est définie à YES, la sortie du module Perl sera\n"
              "bien formatée pour qu'elle puisse être analyse par un lecteur humain. Cela est\n"
              "utile si vous voulez comprendre ce qui se passe. D'un autre côté, si cette\n"
              "balise est définie à NO, la taille de la sortie du module Perl sera beaucoup\n"
              "plus petite et Perl l'analyser de la même manière.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise GENERATE_PERLMOD soit définie sur YES."
          );
  doc->add(
              "PERLMOD_MAKEVAR_PREFIX",
              "Les noms des variables make dans le fichier doxyrules.make généré sont\n"
              "préfixes par la chaîne contenue dans PERLMOD_MAKEVAR_PREFIX. Cela est utile\n"
              "pour que différents fichiers doxyrules.make inclus par le même Makefile\n"
              "n'ecrasent pas les variables les uns des autres.\n"
              "Cette balise nécessite que la balise GENERATE_PERLMOD soit définie sur YES."
          );
  doc->add(
              "ENABLE_PREPROCESSING",
              "Si la balise ENABLE_PREPROCESSING est définie à YES, Doxygen evaluera toutes\n"
              "les directives de préprocesseur C trouvées dans les sources et les fichiers\n"
              "d'inclusion.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "MACRO_EXPANSION",
              "Si la balise MACRO_EXPANSION est définie à YES, Doxygen etendra tous les noms\n"
              "de macros dans le code source. Si défini à NO, seule la compilation\n"
              "conditionnelle sera effectuée. L'expansion de macro peut être faite de manière\n"
              "contrôlée en définissant EXPAND_ONLY_PREDEF à YES.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise ENABLE_PREPROCESSING soit définie sur\n"
              "YES."
          );
  doc->add(
              "EXPAND_ONLY_PREDEF",
              "Si les balises EXPAND_ONLY_PREDEF et MACRO_EXPANSION sont toutes deux définies\n"
              "à YES, alors l'expansion de macro est limitée aux macros spécifiées avec les\n"
              "balises PREDEFINED et EXPAND_AS_DEFINED.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise ENABLE_PREPROCESSING soit définie sur\n"
              "YES."
          );
  doc->add(
              "SEARCH_INCLUDES",
              "Si la balise SEARCH_INCLUDES est définie à YES, les fichiers d'inclusion dans\n"
              "le INCLUDE_PATH seront recherches si un #include est trouvé.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise ENABLE_PREPROCESSING soit définie sur\n"
              "YES."
          );
  doc->add(
              "INCLUDE_PATH",
              "La balise INCLUDE_PATH peut être utilisée pour spécifier un ou plusieurs\n"
              "répertoires qui contiennent des fichiers d'inclusion qui ne sont pas des\n"
              "fichiers d'entrée mais qui doivent être traités par le préprocesseur. Notez\n"
              "que le INCLUDE_PATH n'est pas recursif, donc le paramètre de RECURSIVE n'a\n"
              "aucun effet ici.\n"
              "Cette balise nécessite que la balise SEARCH_INCLUDES soit définie sur YES."
          );
  doc->add(
              "INCLUDE_FILE_PATTERNS",
              "Vous pouvez utiliser la balise INCLUDE_FILE_PATTERNS pour spécifier un ou\n"
              "plusieurs modèles de caractères generiques (comme *.h et *.hpp) pour filtrer\n"
              "les fichiers d'en-tête dans les répertoires. Si laissé vide, les modèles\n"
              "spécifiés avec FILE_PATTERNS seront utilisés.\n"
              "Cette balise nécessite que la balise ENABLE_PREPROCESSING soit définie sur\n"
              "YES."
          );
  doc->add(
              "PREDEFINED",
              "La balise PREDEFINED peut être utilisée pour spécifier un ou plusieurs noms de\n"
              "macros qui sont définis avant que le préprocesseur ne soit lance (similaire à\n"
              "l'option -D de par exemple gcc). L'argument de la balise est une liste de\n"
              "macros de la forme: name ou name=définition (sans espaces). Si la définition\n"
              "et le = sont omis, =1 est suppose. Pour empêcher une définition de macro\n"
              "d'être non définie via #undef ou recursivement développée, utilisez\n"
              "l'opérateur := au lieu de l'opérateur =.\n"
              "Cette balise nécessite que la balise ENABLE_PREPROCESSING soit définie sur\n"
              "YES."
          );
  doc->add(
              "EXPAND_AS_DEFINED",
              "Si les balises MACRO_EXPANSION et EXPAND_ONLY_PREDEF sont définies à YES,\n"
              "cette balise peut être utilisée pour spécifier une liste de noms de macros qui\n"
              "doivent être développées. La définition de macro trouvée dans les sources sera\n"
              "utilisée. Utilisez la balise PREDEFINED si vous voulez utiliser une définition\n"
              "de macro différente qui prime sur la définition trouvée dans le code source.\n"
              "Cette balise nécessite que la balise ENABLE_PREPROCESSING soit définie sur\n"
              "YES."
          );
  doc->add(
              "SKIP_FUNCTION_MACROS",
              "Si la balise SKIP_FUNCTION_MACROS est définie à YES, le préprocesseur de\n"
              "Doxygen supprimera toutes les références aux macros de type fonction qui sont\n"
              "seules sur une ligne, ont un nom entièrement en majuscules et ne se terminent\n"
              "pas par un point-virgule. De telles macros de fonction sont généralement\n"
              "utilisées pour le code standard et perturberont l'analyseur si elles ne sont\n"
              "pas supprimées.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise ENABLE_PREPROCESSING soit définie sur\n"
              "YES."
          );
  doc->add(
              "TAGFILES",
              "La balise TAGFILES peut être utilisée pour spécifier un ou plusieurs fichiers\n"
              "de balises. Pour chaque fichier de balises, l'emplacement de la documentation\n"
              "externe doit être ajouté. Le format d'un fichier de balises sans cet\n"
              "emplacement est le suivant:\n"
              "TAGFILES = file1 file2 ...\n"
              "L'ajout d'un emplacement pour les fichiers de balises se fait comme suit:\n"
              "TAGFILES = file1=loc1 \"file2 = loc2\" ...\n"
              "ou loc1 et loc2 peuvent être des chemins relatifs ou absolus ou des URL. Voir\n"
              "la section \"Linking to external documentation\" pour plus d'informations sur\n"
              "l'utilisation des fichiers de balises.\n"
              "Note : Chaque fichier de balises doit avoir un nom unique (ou le nom n'inclut\n"
              "PAS le chemin). Si un fichier de balises n'est pas situe dans le répertoire\n"
              "dans lequel Doxygen est exécuté, vous devez également spécifier le chemin\n"
              "d'accès au fichier de balises ici."
          );
  doc->add(
              "GENERATE_TAGFILE",
              "Lorsqu'un nom de fichier est spécifié après GENERATE_TAGFILE, Doxygen créera\n"
              "un fichier de balises base sur les fichiers d'entrée qu'il lit. Voir la\n"
              "section \"Linking to external documentation\" pour plus d'informations sur\n"
              "l'utilisation des fichiers de balises."
          );
  doc->add(
              "ALLEXTERNALS",
              "Si la balise ALLEXTERNALS est définie à YES, toutes les classes et namespaces\n"
              "externes seront listés dans l'index des classes et des namespaces. Si défini à\n"
              "NO, seules les classes externes héritées seront listées.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "EXTERNAL_GROUPS",
              "Si la balise EXTERNAL_GROUPS est définie à YES, tous les groupes externes\n"
              "seront listés dans l'index des sujets. Si défini à NO, seuls les groupes du\n"
              "projet actuel seront listés.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "EXTERNAL_PAGES",
              "Si la balise EXTERNAL_PAGES est définie à YES, toutes les pages externes\n"
              "seront listées dans l'index des pages connexes. Si défini à NO, seules les\n"
              "pages du projet actuel seront listées.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "HIDE_UNDOC_RELATIONS",
              "Si défini à YES, les graphes d'héritage et de collaboration cacheront les\n"
              "relations d'héritage et d'utilisation si la cible est non documentée ou n'est\n"
              "pas une classe.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "HAVE_DOT",
              "Si vous définissez la balise HAVE_DOT à YES, Doxygen supposera que l'outil dot\n"
              "est disponible depuis le path. Cet outil fait partie de Graphviz (see:\n"
              "https://www.graphviz.org/), une boite a outils de visualisation de graphes\n"
              "d'AT&T et Lucent Bell Labs. Les autres options de cette section n'ont aucun\n"
              "effet si cette option est définie à NO.\n"
              "La valeur par défaut est : NO."
          );
  doc->add(
              "DOT_NUM_THREADS",
              "Le DOT_NUM_THREADS spécifie le nombre d'invocations dot que Doxygen est\n"
              "autorisé à exécuter en parallele. Lorsqu'il est défini à 0, Doxygen le basera\n"
              "sur le nombre de processeurs disponibles dans le système. Vous pouvez le\n"
              "définir explicitement à une valeur supérieure à 0 pour avoir un contrôle sur\n"
              "l'équilibre entre la charge CPU et la vitesse de traitement.\n"
              "Valeur minimum : 0, valeur maximum : 512, valeur par défaut : 0.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "DOT_BATCH_SIZE",
              "Le DOT_BATCH_SIZE spécifie le nombre de graphiques dot que Doxygen est\n"
              "autorisé à compiler en une seule invocation de dot. Lorsqu'il est défini sur\n"
              "1, Doxygen invoquera dot pour chaque graphique séparément, ce qui peut\n"
              "entrainer une surcharge significative de création de processus, en particulier\n"
              "sur les systèmes avec de nombreux cœurs de CPU. Ensemble avec DOT_NUM_THREADS,\n"
              "ce paramètre peut être utilisé pour optimiser la vitesse de traitement de dot\n"
              "pour un système particulier. Doxygen essaiera d'attribuer à chaque thread une\n"
              "charge de travail équilibrée. Si le nombre total de graphiques a traiter\n"
              "dépasse DOT_NUM_THREADS * DOT_BATCH_SIZE, des lots supplémentaires seront\n"
              "créés pour que dot les traite.\n"
              "Valeur minimum : 1, valeur maximum : 1000, valeur par défaut : 50.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "DOT_COMMON_ATTR",
              "DOT_COMMON_ATTR est des attributs communs pour les nœuds, les arêtes et les\n"
              "étiquettes de sous-graphes. Lorsque vous voulez une police d'apparence\n"
              "différente dans les fichiers dot que Doxygen génère, vous pouvez spécifier les\n"
              "attributs fontname, fontcolor et fontsize. Pour plus de détails, voir <a\n"
              "href=https://graphviz.org/doc/info/attrs.html>spécification des attributs de\n"
              "Nœud, Arête et Graphe</a>. Vous devez vous assurer que dot est capable de\n"
              "trouver la police, ce qui peut être fait en la placant dans un emplacement\n"
              "standard ou en définissant la variable d'environnement DOTFONTPATH ou en\n"
              "définissant DOT_FONTPATH sur le répertoire contenant la police. La taille de\n"
              "police graphviz par défaut est 14.\n"
              "La valeur par défaut est : fontname=Helvetica,fontsize=10.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "DOT_EDGE_ATTR",
              "DOT_EDGE_ATTR est concatene avec DOT_COMMON_ATTR. Pour un style elegant, vous\n"
              "pouvez ajouter 'arrowhead=open, arrowtail=open, arrowsize=0.5'. <a\n"
              "href=https://graphviz.org/doc/info/arrows.html>Documentation complète sur les\n"
              "formes de flèches.</a>\n"
              "La valeur par défaut est : labelfontname=Helvetica,labelfontsize=10.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "DOT_NODE_ATTR",
              "DOT_NODE_ATTR est concatene avec DOT_COMMON_ATTR. Pour une vue sans boites\n"
              "autour des nœuds, définissez 'shape=plain' ou 'shape=plaintext'. <a\n"
              "href=https://www.graphviz.org/doc/info/shapes.html>Spécification des\n"
              "formes.</a>\n"
              "La valeur par défaut est : shape=box,height=0.2,width=0.4.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "DOT_FONTPATH",
              "Vous pouvez définir le chemin ou dot peut trouver la police spécifiée avec\n"
              "fontname dans DOT_COMMON_ATTR et d'autres attributs dot.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "CLASS_GRAPH",
              "Si la balise CLASS_GRAPH est définie à YES ou GRAPH ou BUILTIN, Doxygen\n"
              "générera un graphe pour chaque classe documentée montrant les relations\n"
              "d'héritage directes et indirectes. Si la balise CLASS_GRAPH est définie à YES\n"
              "ou GRAPH et que HAVE_DOT est activé également, alors dot sera utilisé pour\n"
              "dessiner le graphe. Si la balise CLASS_GRAPH est définie à YES et que HAVE_DOT\n"
              "est désactivé ou si la balise CLASS_GRAPH est définie à BUILTIN, alors le\n"
              "generateur intégré sera utilisé. Si la balise CLASS_GRAPH est définie à TEXT,\n"
              "les relations d'héritage directes et indirectes seront affichées sous forme de\n"
              "textes / liens. L'activation explicite d'un graphe d'héritage ou le choix\n"
              "d'une representation différente pour un graphe d'héritage d'une classe\n"
              "spécifique peut être accompli au moyen de la commande \\inheritancegraph. La\n"
              "désactivation d'un graphe d'héritage peut être accomplie au moyen de la\n"
              "commande \\hideinheritancegraph.\n"
              "Les valeurs possibles sont :NO, YES, TEXT, GRAPHetBUILTIN.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "COLLABORATION_GRAPH",
              "Si la balise COLLABORATION_GRAPH est définie à YES, Doxygen générera un graphe\n"
              "pour chaque classe documentée montrant les dépendances d'implémentation\n"
              "directes et indirectes (héritage, containment et variables de référence de\n"
              "classe) de la classe avec d'autres classes documentées. L'activation explicite\n"
              "d'un graphe de collaboration, lorsque COLLABORATION_GRAPH est défini à NO,\n"
              "peut être accomplie au moyen de la commande \\collaborationgraph. La\n"
              "désactivation d'un graphe de collaboration peut être accomplie au moyen de la\n"
              "commande \\hidecollaborationgraph.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "GROUP_GRAPHS",
              "Si la balise GROUP_GRAPHS est définie à YES, Doxygen générera un graphe pour\n"
              "les groupes, montrant les dépendances directes des groupes. L'activation\n"
              "explicite d'un graphe de dépendance de groupe, lorsque GROUP_GRAPHS est défini\n"
              "à NO, peut être accomplie au moyen de la commande \\groupgraph. La\n"
              "désactivation d'un graphe de répertoire peut être accomplie au moyen de la\n"
              "commande \\hidegroupgraph. Voir aussi le chapitre Grouping dans le manuel.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "UML_LOOK",
              "Si la balise UML_LOOK est définie à YES, Doxygen générera des diagrammes\n"
              "d'héritage et de collaboration dans un style similaire au langage de\n"
              "modelisation unifie de l'OMG.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "UML_LIMIT_NUM_FIELDS",
              "Si la balise UML_LOOK est activée, les champs et méthodes sont affichés à\n"
              "l'intérieur du nœud de classe. S'il y a beaucoup de champs ou méthodes et\n"
              "beaucoup de nœuds, le graphe peut devenir trop grand pour être utile. Le seuil\n"
              "UML_LIMIT_NUM_FIELDS limite le nombre d'éléments pour chaque type pour rendre\n"
              "la taille plus gérable. Définissez ceci à 0 pour aucune limite. Notez que le\n"
              "seuil peut être dépasse de 50% avant que la limite ne soit appliquée. Donc\n"
              "lorsque vous définissez le seuil à 10, jusqu'à 15 champs peuvent apparaître,\n"
              "mais si le nombre dépasse 15, le nombre total de champs affichés est limite à\n"
              "10.\n"
              "Valeur minimum : 0, valeur maximum : 100, valeur par défaut : 10.\n"
              "Cette balise nécessite que la balise UML_LOOK soit définie sur YES."
          );
  doc->add(
              "UML_MAX_EDGE_LABELS",
              "Si la balise UML_LOOK est activée, les étiquettes de champ sont affichées le\n"
              "long de l'arête entre deux nœuds de classe. S'il y a beaucoup de champs et\n"
              "beaucoup de nœuds, le graphe peut devenir trop encombre. Le seuil\n"
              "UML_MAX_EDGE_LABELS limite le nombre d'éléments pour rendre la taille plus\n"
              "gérable. Définissez ceci à 0 pour aucune limite.\n"
              "Valeur minimum : 0, valeur maximum : 100, valeur par défaut : 10.\n"
              "Cette balise nécessite que la balise UML_LOOK soit définie sur YES."
          );
  doc->add(
              "DOT_UML_DETAILS",
              "Si la balise DOT_UML_DETAILS est définie à NO, Doxygen affichera les attributs\n"
              "et méthodes sans types et arguments dans les graphes UML. Si la balise\n"
              "DOT_UML_DETAILS est définie à YES, Doxygen ajoutera le type et les arguments\n"
              "pour les attributs et méthodes dans les graphes UML. Si la balise\n"
              "DOT_UML_DETAILS est définie à NONE, Doxygen ne générera pas de champs avec des\n"
              "informations de membre de classe dans les graphes UML. Les diagrammes de\n"
              "classe ressembleront aux diagrammes de classe par défaut mais en utilisant la\n"
              "notation UML pour les relations.\n"
              "Les valeurs possibles sont :NO, YESetNONE.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise UML_LOOK soit définie sur YES."
          );
  doc->add(
              "DOT_WRAP_THRESHOLD",
              "La balise DOT_WRAP_THRESHOLD peut être utilisée pour définir le nombre maximal\n"
              "de caractères a afficher sur une seule ligne. Si la longueur réelle de la\n"
              "ligne dépasse significativement ce seuil, elle sera divisée sur plusieurs\n"
              "lignes. Quelques heuristiques sont appliquées pour éviter les coupures de\n"
              "ligne inesthetiques.\n"
              "Valeur minimum : 0, valeur maximum : 1000, valeur par défaut : 17.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "TEMPLATE_RELATIONS",
              "Si la balise TEMPLATE_RELATIONS est définie à YES, les graphes d'héritage et\n"
              "de collaboration montreront les relations entre les templates et leurs\n"
              "instances.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "INCLUDE_GRAPH",
              "Si les balises INCLUDE_GRAPH, ENABLE_PREPROCESSING et SEARCH_INCLUDES sont\n"
              "définies à YES, Doxygen générera un graphe pour chaque fichier documente\n"
              "montrant les dépendances d'inclusion directes et indirectes du fichier avec\n"
              "d'autres fichiers documentés. L'activation explicite d'un graphe d'inclusion,\n"
              "lorsque INCLUDE_GRAPH est défini à NO, peut être accomplie au moyen de la\n"
              "commande \\includegraph. La désactivation d'un graphe d'inclusion peut être\n"
              "accomplie au moyen de la commande \\hideincludegraph.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "INCLUDED_BY_GRAPH",
              "Si les balises INCLUDED_BY_GRAPH, ENABLE_PREPROCESSING et SEARCH_INCLUDES sont\n"
              "définies à YES, Doxygen générera un graphe pour chaque fichier documente\n"
              "montrant les dépendances d'inclusion directes et indirectes du fichier avec\n"
              "d'autres fichiers documentés. L'activation explicite d'un graphe d'inclusion\n"
              "par, lorsque INCLUDED_BY_GRAPH est défini à NO, peut être accomplie au moyen\n"
              "de la commande \\includedbygraph. La désactivation d'un graphe d'inclusion par\n"
              "peut être accomplie au moyen de la commande \\hideincludedbygraph.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "CALL_GRAPH",
              "Si la balise CALL_GRAPH est définie à YES, Doxygen générera un graphe de\n"
              "dépendance d'appel pour chaque fonction globale ou méthode de classe.\n"
              "\n"
              "Notez que l'activation de cette option augmentera de manière significative le\n"
              "temps d'une exécution. Donc dans la plupart des cas, il sera préférable\n"
              "d'activer les graphes d'appel uniquement pour les fonctions sélectionnées en\n"
              "utilisant la commande \\callgraph. La désactivation d'un graphe d'appel peut\n"
              "être accomplie au moyen de la commande \\hidecallgraph.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "CALLER_GRAPH",
              "Si la balise CALLER_GRAPH est définie à YES, Doxygen générera un graphe de\n"
              "dépendance d'appelant pour chaque fonction globale ou méthode de classe.\n"
              "\n"
              "Notez que l'activation de cette option augmentera de manière significative le\n"
              "temps d'une exécution. Donc dans la plupart des cas, il sera préférable\n"
              "d'activer les graphes d'appelant uniquement pour les fonctions sélectionnées\n"
              "en utilisant la commande \\callergraph. La désactivation d'un graphe d'appelant\n"
              "peut être accomplie au moyen de la commande \\hidecallergraph.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "GRAPHICAL_HIERARCHY",
              "Si la balise GRAPHICAL_HIERARCHY est définie à YES, Doxygen générera une\n"
              "hiérarchie graphique de toutes les classes au lieu d'une textuelle.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "DIRECTORY_GRAPH",
              "Si la balise DIRECTORY_GRAPH est définie à YES, Doxygen montrera les\n"
              "dépendances d'un répertoire sur d'autres répertoires de manière graphique. Les\n"
              "relations de dépendance sont déterminées par les relations #include entre les\n"
              "fichiers dans les répertoires. L'activation explicite d'un graphe de\n"
              "répertoire, lorsque DIRECTORY_GRAPH est défini à NO, peut être accomplie au\n"
              "moyen de la commande \\directorygraph. La désactivation d'un graphe de\n"
              "répertoire peut être accomplie au moyen de la commande \\hidedirectorygraph.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "DIR_GRAPH_MAX_DEPTH",
              "La balise DIR_GRAPH_MAX_DEPTH peut être utilisée pour limiter le nombre\n"
              "maximal de niveaux de sous-répertoires générés dans les graphes de dépendance\n"
              "de répertoire par dot.\n"
              "Valeur minimum : 1, valeur maximum : 25, valeur par défaut : 1.\n"
              "Cette balise nécessite que la balise DIRECTORY_GRAPH soit définie sur YES."
          );
  doc->add(
              "DOT_IMAGE_FORMAT",
              "La balise DOT_IMAGE_FORMAT peut être utilisée pour définir le format d'image\n"
              "des images générées par dot. Pour une explication des formats d'image, voir la\n"
              "section des formats de sortie dans la documentation de l'outil dot (Graphviz\n"
              "(see:\n"
              "https://www.graphviz.org/)).\n"
              "\n"
              "Notez que les formats svg:cairo et svg:cairo:cairo ne peuvent pas être\n"
              "utilisés en combinaison avec INTERACTIVE_SVG (le INTERACTIVE_SVG sera défini a\n"
              "NO).\n"
              "Les valeurs possibles sont :png, jpg, gif, svg, png:gd, png:gd:gd, png:cairo,\n"
              "png:cairo:gd, png:cairo:cairo, png:cairo:gdiplus, png:gdiplus,\n"
              "png:gdiplus:gdiplus, svg:cairo, svg:cairo:cairo, svg:svg, svg:svg:core,\n"
              "gif:cairo, gif:cairo:gd, gif:cairo:gdiplus, gif:gdiplus, gif:gdiplus:gdiplus,\n"
              "gif:gd, gif:gd:gd, jpg:cairo, jpg:cairo:gd, jpg:cairo:gdiplus, jpg:gd,\n"
              "jpg:gd:gd, jpg:gdiplusetjpg:gdiplus:gdiplus.\n"
              "La valeur par défaut est : png.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "INTERACTIVE_SVG",
              "Si DOT_IMAGE_FORMAT est défini a svg ou svg:svg ou svg:svg:core, cette option\n"
              "peut être définie à YES pour activer la génération d'images SVG interactives\n"
              "qui permettent le zoom et le panoramique.\n"
              "\n"
              "Notez que cela nécessite un navigateur moderne autre qu'Internet Explorer.\n"
              "Testes et fonctionnels: Firefox, Chrome, Safari et Opera.\n"
              "\n"
              "Notez que cette option sera automatiquement désactivée lorsque\n"
              "DOT_IMAGE_FORMAT est défini a svg:cairo ou svg:cairo:cairo.\n"
              "La valeur par défaut est : NO.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "DOT_PATH",
              "La balise DOT_PATH peut être utilisée pour spécifier le chemin ou l'outil dot\n"
              "peut être trouvé. Si laissé vide, il est suppose que l'outil dot peut être\n"
              "trouvé dans le path.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "DOTFILE_DIRS",
              "La balise DOTFILE_DIRS peut être utilisée pour spécifier un ou plusieurs\n"
              "répertoires qui contiennent des fichiers dot qui sont inclus dans la\n"
              "documentation (voir la commande \\dotfile).\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "DIA_PATH",
              "Vous pouvez inclure des diagrammes faits avec dia dans la documentation\n"
              "Doxygen. Doxygen executera ensuite dia pour produire le diagramme et l'insérer\n"
              "dans la documentation. La balise DIA_PATH vous permet de spécifier le\n"
              "répertoire ou reside le binaire dia. Si laissé vide, dia est suppose être\n"
              "trouve dans le chemin de recherche par défaut."
          );
  doc->add(
              "DIAFILE_DIRS",
              "La balise DIAFILE_DIRS peut être utilisée pour spécifier un ou plusieurs\n"
              "répertoires qui contiennent des fichiers dia qui sont inclus dans la\n"
              "documentation (voir la commande \\diafile)."
          );
  doc->add(
              "PLANTUML_JAR_PATH",
              "Lors de l'utilisation de PlantUML, la balise PLANTUML_JAR_PATH devrait être\n"
              "utilisée pour spécifier le chemin ou java peut trouver le fichier plantuml.jar\n"
              "ou le nom de fichier du fichier jar a utiliser. Si laissé vide, il est suppose\n"
              "que PlantUML n'est pas utilise ou appelé lors d'une étape de prétraitement.\n"
              "Doxygen générera un avertissement lorsqu'il rencontrera une commande \\startuml\n"
              "dans ce cas et ne générera pas de sortie pour le diagramme."
          );
  doc->add(
              "PLANTUML_CFG_FILE",
              "Lors de l'utilisation de PlantUML, la balise PLANTUML_CFG_FILE peut être\n"
              "utilisée pour spécifier un fichier de configuration pour PlantUML."
          );
  doc->add(
              "PLANTUML_INCLUDE_PATH",
              "Lors de l'utilisation de PlantUML, les chemins spécifiés sont recherches pour\n"
              "les fichiers spécifiés par l'instruction !include dans un bloc PlantUML."
          );
  doc->add(
              "PLANTUMLFILE_DIRS",
              "La balise PLANTUMLFILE_DIRS peut être utilisée pour spécifier un ou plusieurs\n"
              "répertoires qui contiennent des fichiers PlantUml qui sont inclus dans la\n"
              "documentation (voir la commande \\plantumlfile)."
          );
  doc->add(
              "MERMAID_PATH",
              "Lors de l'utilisation de diagrammes Mermaid avec le rendu CLI, la balise\n"
              "MERMAID_PATH devrait être utilisée pour spécifier le répertoire ou\n"
              "l'exécutable mmdc (Mermaid CLI) peut être trouvé. Si laissé vide, le rendu\n"
              "basé sur CLI est désactivé. Pour la sortie HTML, le rendu côté client via\n"
              "JavaScript est utilisé par défaut et ne nécessite pas mmdc. Pour la sortie\n"
              "LaTeX/PDF, mmdc est requis pour pre-générer les images. Doxygen générera un\n"
              "avertissement lorsque le rendu CLI est nécessaire mais que mmdc n'est pas\n"
              "disponible."
          );
  doc->add(
              "MERMAID_CONFIG_FILE",
              "Lors de l'utilisation de diagrammes Mermaid, la balise MERMAID_CONFIG_FILE\n"
              "peut être utilisée pour spécifier un fichier de configuration JSON pour\n"
              "l'outil Mermaid CLI (mmdc). Ce fichier peut contenir des paramètres de thème\n"
              "et d'autres options de configuration Mermaid."
          );
  doc->add(
              "MERMAID_RENDER_MODE",
              "La balise MERMAID_RENDER_MODE sélectionne la manière dont les diagrammes\n"
              "Mermaid sont rendus.\n"
              "Les valeurs possibles sont :AUTO (utiliser le rendu côté client pour HTML et\n"
              "mmdc pour LaTeX/PDF et autres formats. Si MERMAID_PATH n'est pas défini, les\n"
              "diagrammes non-HTML produiront un avertissement), CLI (utiliser l'outil mmdc\n"
              "pour pre-générer les images (nécessite Node.js et mermaid-js/mermaid-cli).\n"
              "Fonctionne pour tous les formats de sortie)etCLIENT_SIDE (integrer mermaid.js\n"
              "dans la sortie HTML pour le rendu côté client. Ne nécessite pas mmdc mais\n"
              "fonctionne uniquement pour la sortie HTML).\n"
              "La valeur par défaut est : AUTO."
          );
  doc->add(
              "MERMAID_JS_URL",
              "La balise MERMAID_JS_URL spécifie l'URL à partir de laquelle charger\n"
              "mermaid.js lors de l'utilisation du rendu côté client (MERMAID_RENDER_MODE est\n"
              "CLIENT_SIDE ou AUTO). Le défaut pointe vers la dernière version Mermaid v11\n"
              "sur le CDN jsDelivr.\n"
              "\n"
              "L'URL CDN par défaut nécessite un accès Internet lors de la consultation de\n"
              "la documentation générée. Pour une utilisation hors ligne, telechargez\n"
              "mermaid.esm.min.mjs et définissez ceci sur un chemin relatif, ou utilisez\n"
              "MERMAID_RENDER_MODE=CLI pour pre-générer les images à la place.\n"
              "Exemples:\n"
              "- Dernière v11 (défaut):\n"
              "https://cdn.jsdelivr.net/npm/mermaid@11/dist/mermaid.esm.min.mjs\n"
              "- Version épinglée:\n"
              "https://cdn.jsdelivr.net/npm/mermaid@11.3.0/dist/mermaid.esm.min.mjs\n"
              "- Copie locale: ./mermaid.esm.min.mjs (l'utilisateur doit placer le fichier\n"
              "dans le répertoire de sortie HTML)\n"
              "La valeur par défaut est :\n"
              "https://cdn.jsdelivr.net/npm/mermaid@11/dist/mermaid.esm.min.mjs."
          );
  doc->add(
              "MERMAIDFILE_DIRS",
              "La balise MERMAIDFILE_DIRS peut être utilisée pour spécifier un ou plusieurs\n"
              "répertoires qui contiennent des fichiers Mermaid qui sont inclus dans la\n"
              "documentation (voir la commande \\mermaidfile)."
          );
  doc->add(
              "DOT_GRAPH_MAX_NODES",
              "La balise DOT_GRAPH_MAX_NODES peut être utilisée pour définir le nombre\n"
              "maximal de nœuds qui seront affichés dans le graphe. Si le nombre de nœuds\n"
              "dans un graphe devient supérieur à cette valeur, Doxygen tronquera le graphe,\n"
              "ce qui est visualise en représentant un nœud comme une boite rouge. Notez que\n"
              "si le nombre d'enfants directs du nœud racine dans un graphe est déjà\n"
              "supérieur à DOT_GRAPH_MAX_NODES, le graphe ne sera pas affiche du tout. Notez\n"
              "également que la taille d'un graphe peut être encore restreinte par\n"
              "MAX_DOT_GRAPH_DEPTH.\n"
              "Valeur minimum : 0, valeur maximum : 10000, valeur par défaut : 50.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "MAX_DOT_GRAPH_DEPTH",
              "La balise MAX_DOT_GRAPH_DEPTH peut être utilisée pour définir la profondeur\n"
              "maximale des graphes générés par dot. Une valeur de profondeur de 3 signifie\n"
              "que seuls les nœuds atteignables depuis la racine en suivant un chemin via au\n"
              "maximum 3 arêtes seront affichés. Les nœuds qui se trouvent plus loin du nœud\n"
              "racine seront omis. Notez que définir cette option à 1 ou 2 peut réduire\n"
              "considerablement le temps de calcul nécessaire pour les grandes bases de code.\n"
              "Notez également que la taille d'un graphe peut être encore restreinte par\n"
              "DOT_GRAPH_MAX_NODES. Utiliser une profondeur de 0 signifie aucune restriction\n"
              "de profondeur.\n"
              "Valeur minimum : 0, valeur maximum : 1000, valeur par défaut : 0.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "GENERATE_LEGEND",
              "Si la balise GENERATE_LEGEND est définie à YES, Doxygen générera une page de\n"
              "legende expliquant la signification des diverses boites et flèches dans les\n"
              "graphes générés par dot.\n"
              "Note : Cette balise nécessite que UML_LOOK ne soit pas défini, c'est-à-dire\n"
              "que la representation graphique interne de Doxygen pour les diagrammes\n"
              "d'héritage et de collaboration soit utilisée.\n"
              "La valeur par défaut est : YES.\n"
              "Cette balise nécessite que la balise HAVE_DOT soit définie sur YES."
          );
  doc->add(
              "DOT_CLEANUP",
              "Si la balise DOT_CLEANUP est définie à YES, Doxygen supprimera les fichiers\n"
              "intermédiaires qui sont utilisés pour générer les divers graphes.\n"
              "\n"
              "Note: Ce paramètre est utilisé non seulement pour les fichiers dot mais aussi\n"
              "pour les fichiers temporaires msc.\n"
              "La valeur par défaut est : YES."
          );
  doc->add(
              "MSCGEN_TOOL",
              "Vous pouvez définir des diagrammes de séquence de messages dans les\n"
              "commentaires Doxygen en utilisant la commande \\msc. Si la balise MSCGEN_TOOL\n"
              "est laissée vide (le défaut), Doxygen utilisera une version intégrée de\n"
              "l'outil mscgen pour produire les diagrammes. Alternativement, la balise\n"
              "MSCGEN_TOOL peut également spécifier le nom d'un outil externe. Par exemple,\n"
              "en specifiant prog comme valeur, Doxygen appellera l'outil comme prog -T\n"
              "<outfile_format> -o <outputfile> <inputfile>. L'outil externe devrait prendre\n"
              "en charge les formats de fichier de sortie \"png\", \"eps\", \"svg\" et \"ismap\"."
          );
  doc->add(
              "MSCFILE_DIRS",
              "La balise MSCFILE_DIRS peut être utilisée pour spécifier un ou plusieurs\n"
              "répertoires qui contiennent des fichiers msc qui sont inclus dans la\n"
              "documentation (voir la commande \\mscfile)."
          );
}
